<?php
namespace BdevsElement\Widget;

use \Elementor\Group_Control_Background;
use \Elementor\Repeater;
use \Elementor\Controls_Manager;
use \Elementor\Group_Control_Border;
use \Elementor\Group_Control_Image_Size;
use \Elementor\Group_Control_Typography;
use \Elementor\Scheme_Typography;
use \Elementor\Utils;

defined( 'ABSPATH' ) || die();

class Testimonial_Slider extends BDevs_El_Widget {

    /**
     * Get widget name.
     *
     * Retrieve Bdevs Element widget name.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget name.
     */
    public function get_name() {
        return 'testimonial_slider';
    }

    /**
     * Get widget title.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget title.
     */
    public function get_title() {
        return __( 'Testimonial Slider', 'bdevselement' );
    }

	public function get_custom_help_url() {
		return 'http://elementor.bdevs.net//widgets/slider/';
	}

    /**
     * Get widget icon.
     *
     * @since 1.0.0
     * @access public
     *
     * @return string Widget icon.
     */
    public function get_icon() {
        return 'eicon-blockquote';
    }

    public function get_keywords() {
        return [ 'slider', 'testimonial', 'gallery', 'carousel' ];
    }

    protected function register_content_controls() {


        $this->start_controls_section(
            '_section_design_title',
            [
                'label' => __( 'Design Style', 'bdevselement' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
        $this->add_control(
            'design_style',
            [
                'label' => __( 'Design Style', 'bdevselement' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style_1' => __( 'Style 1', 'bdevselement' ),
                    'style_2' => __( 'Style 2', 'bdevselement' ),
                    'style_3' => __( 'Style 3: Home 3', 'bdevselement' ),
                    'style_4' => __( 'Style 4: 3-items', 'bdevselement' ),
                ],
                'default' => 'style_1',
                'frontend_available' => true,
                'style_transfer' => true,
            ]
        );

        $this->end_controls_section(); 


        // section title
        $this->start_controls_section(
            '_section_title',
            [
                'label' => __( 'Title & Description', 'bdevselement' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'big_title',
            [
                'label' => __( 'Big Title', 'bdevselement' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __( 'Big Title', 'bdevselement' ),
                'placeholder' => __( 'big Title', 'bdevselement' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'sub_title',
            [
                'label' => __( 'Sub Title', 'bdevselement' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __( 'bdevs Info Box Sub Title', 'bdevselement' ),
                'placeholder' => __( 'Type Info Box Sub Title', 'bdevselement' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => __( 'Title', 'bdevselement' ),
                'label_block' => true,
                'type' => Controls_Manager::TEXT,
                'default' => __( 'bdevs Info Box Title', 'bdevselement' ),
                'placeholder' => __( 'Type Info Box Title', 'bdevselement' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'description',
            [
                'label' => __( 'Description', 'bdevselement' ),
                'description' => bdevs_element_get_allowed_html_desc( 'intermediate' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => __( 'bdevs info box description goes here', 'bdevselement' ),
                'placeholder' => __( 'Type info box description', 'bdevselement' ),
                'rows' => 5,
                'condition' => [
                    'design_style' => ['style_10']
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );   

        $this->add_control(
            'default_image',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Default Image', 'bdevselement' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'design_style' => ['style_2', 'style_3']
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );      
       

        $this->add_control(
            'title_tag',
            [
                'label' => __( 'Title HTML Tag', 'bdevselement' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'h1'  => [
                        'title' => __( 'H1', 'bdevselement' ),
                        'icon' => 'eicon-editor-h1'
                    ],
                    'h2'  => [
                        'title' => __( 'H2', 'bdevselement' ),
                        'icon' => 'eicon-editor-h2'
                    ],
                    'h3'  => [
                        'title' => __( 'H3', 'bdevselement' ),
                        'icon' => 'eicon-editor-h3'
                    ],
                    'h4'  => [
                        'title' => __( 'H4', 'bdevselement' ),
                        'icon' => 'eicon-editor-h4'
                    ],
                    'h5'  => [
                        'title' => __( 'H5', 'bdevselement' ),
                        'icon' => 'eicon-editor-h5'
                    ],
                    'h6'  => [
                        'title' => __( 'H6', 'bdevselement' ),
                        'icon' => 'eicon-editor-h6'
                    ]
                ],
                'default' => 'h2',
                'toggle' => false,
            ]
        );

        $this->add_responsive_control(
            'align',
            [
                'label' => __( 'Alignment', 'bdevselement' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'bdevselement' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'bdevselement' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'bdevselement' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}}' => 'text-align: {{VALUE}};'
                ]
            ]
        );

        $this->end_controls_section(); 
        
        $this->start_controls_section(
            '_section_right_iamge',
            [
                'label' => __( 'Right Image', 'bdevselement' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        ); 

        $this->add_control(
            'right_img_switch',
            [
                'label' => __( 'Display Right Image', 'bdevselement' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'bdevselement' ),
                'label_off' => __( 'Hide', 'bdevselement' ),
                'return_value' => 'yes',
                'default' => 'yes',
                'style_transfer' => true,
            ]
        );

        $this->add_control(
            'right_image_1',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Deco Image 1', 'bdevselement' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        ); 
        $this->add_control(
            'right_image_2',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Deco Image 2', 'bdevselement' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        ); 

        $this->add_control(
            'right_image_3',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Deco Image 3', 'bdevselement' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        ); 

        $this->add_control(
            'right_image_4',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Deco Image 4', 'bdevselement' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );   

        $this->add_control(
            'right_image_5',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Shape Image 1', 'bdevselement' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );  

        $this->add_control(
            'right_image_6',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Shape Image 2', 'bdevselement' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );  

        $this->end_controls_section();   

        $this->start_controls_section(
            '_section_slides',
            [
                'label' => __( 'Slides', 'bdevselement' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $repeater = new Repeater();

         $repeater->add_control(
            'field_condition',
            [
                'label' => __( 'Field condition', 'bdevselement' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'style_1' => __( 'Style 1', 'bdevselement' ),
                    'style_2' => __( 'Style 2', 'bdevselement' ),  
                    'style_3' => __( 'Style 3', 'bdevselement' ), 
                    'style_4' => __( 'Style 4: 3-items', 'bdevselement' ),      
                ],
                'default' => 'style_1',
                'frontend_available' => true,
                'style_transfer' => true,
            ]
        );

        $repeater->add_control(
            'bg_image',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'Quote Image', 'bdevselement' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'condition' => [
                    'field_condition' => ['style_1', 'style_2', 'style_3', 'style_4']
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );           

        $repeater->add_control(
            'image',
            [
                'type' => Controls_Manager::MEDIA,
                'label' => __( 'profile Image', 'bdevselement' ),
                'default' => [
                    'url' => Utils::get_placeholder_image_src(),
                ],
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );        

        $repeater->add_control(
            'title',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'label' => __( 'Title', 'bdevselement' ),
                'placeholder' => __( 'Type title here', 'bdevselement' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'message',
            [
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'show_label' => false,
                'placeholder' => __( 'Message', 'bdevselement' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $repeater->add_control(
            'client_name',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'show_label' => false,
                'placeholder' => __( 'Client Name', 'bdevselement' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );        

        $repeater->add_control(
            'designation_name',
            [
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'show_label' => false,
                'placeholder' => __( 'Designation Name', 'bdevselement' ),
                'dynamic' => [
                    'active' => true,
                ]
            ]
        );

        $this->add_control(
            'slides',
            [
                'show_label' => false,
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'title_field' => '<# print(title || "Carousel Item"); #>',
                'default' => [
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                    [
                        'image' => [
                            'url' => Utils::get_placeholder_image_src(),
                        ],
                    ],
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'thumbnail',
                'default' => 'medium_large',
                'separator' => 'before',
                'exclude' => [
                    'custom'
                ]
            ]
        );

        $this->end_controls_section();

    }

    protected function register_style_controls() {
        $this->start_controls_section(
            '_section_style_item',
            [
                'label' => __( 'Slider Item', 'bdevselement' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'item_border',
                'selector' => '{{WRAPPER}} .bdevs-slick-item',
            ]
        );

        $this->add_responsive_control(
            'item_border_radius',
            [
                'label' => __( 'Border Radius', 'bdevselement' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-slick-item' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}; overflow: hidden;',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_style_content',
            [
                'label' => __( 'Slide Content', 'bdevselement' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'content_padding',
            [
                'label' => __( 'Content Padding', 'bdevselement' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', 'em', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-slick-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'content_background',
                'selector' => '{{WRAPPER}} .bdevs-slick-content',
                'exclude' => [
                    'image'
                ]
            ]
        );

        $this->add_control(
            '_heading_title',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Title', 'bdevselement' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => __( 'Bottom Spacing', 'bdevselement' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-slick-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => __( 'Text Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-slick-title' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title',
                'selector' => '{{WRAPPER}} .bdevs-slick-title',
                'scheme' => Scheme_Typography::TYPOGRAPHY_2,
            ]
        );

        $this->add_control(
            '_heading_subtitle',
            [
                'type' => Controls_Manager::HEADING,
                'label' => __( 'Subtitle', 'bdevselement' ),
                'separator' => 'before'
            ]
        );

        $this->add_responsive_control(
            'subtitle_spacing',
            [
                'label' => __( 'Bottom Spacing', 'bdevselement' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .bdevs-slick-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'subtitle_color',
            [
                'label' => __( 'Text Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .bdevs-slick-subtitle' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'subtitle',
                'selector' => '{{WRAPPER}} .bdevs-slick-subtitle',
                'scheme' => Scheme_Typography::TYPOGRAPHY_3,
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_style_arrow',
            [
                'label' => __( 'Navigation - Arrow', 'bdevselement' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'arrow_position_toggle',
            [
                'label' => __( 'Position', 'bdevselement' ),
                'type' => Controls_Manager::POPOVER_TOGGLE,
                'label_off' => __( 'None', 'bdevselement' ),
                'label_on' => __( 'Custom', 'bdevselement' ),
                'return_value' => 'yes',
            ]
        );

        $this->start_popover();

        $this->add_responsive_control(
            'arrow_position_y',
            [
                'label' => __( 'Vertical', 'bdevselement' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'condition' => [
                    'arrow_position_toggle' => 'yes'
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .slick-prev, {{WRAPPER}} .slick-next' => 'top: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'arrow_position_x',
            [
                'label' => __( 'Horizontal', 'bdevselement' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'condition' => [
                    'arrow_position_toggle' => 'yes'
                ],
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 250,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .slick-prev' => 'left: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .slick-next' => 'right: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_popover();

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'arrow_border',
                'selector' => '{{WRAPPER}} .slick-prev, {{WRAPPER}} .slick-next',
            ]
        );

        $this->add_responsive_control(
            'arrow_border_radius',
            [
                'label' => __( 'Border Radius', 'bdevselement' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .slick-prev, {{WRAPPER}} .slick-next' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}; overflow: hidden;',
                ],
            ]
        );

        $this->start_controls_tabs( '_tabs_arrow' );

        $this->start_controls_tab(
            '_tab_arrow_normal',
            [
                'label' => __( 'Normal', 'bdevselement' ),
            ]
        );

        $this->add_control(
            'arrow_color',
            [
                'label' => __( 'Text Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .slick-prev, {{WRAPPER}} .slick-next' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'arrow_bg_color',
            [
                'label' => __( 'Background Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-prev, {{WRAPPER}} .slick-next' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            '_tab_arrow_hover',
            [
                'label' => __( 'Hover', 'bdevselement' ),
            ]
        );

        $this->add_control(
            'arrow_hover_color',
            [
                'label' => __( 'Text Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-prev:hover, {{WRAPPER}} .slick-next:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'arrow_hover_bg_color',
            [
                'label' => __( 'Background Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-prev:hover, {{WRAPPER}} .slick-next:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'arrow_hover_border_color',
            [
                'label' => __( 'Border Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'condition' => [
                    'arrow_border_border!' => '',
                ],
                'selectors' => [
                    '{{WRAPPER}} .slick-prev:hover, {{WRAPPER}} .slick-next:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();

        $this->start_controls_section(
            '_section_style_dots',
            [
                'label' => __( 'Navigation - Dots', 'bdevselement' ),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'dots_nav_position_y',
            [
                'label' => __( 'Vertical Position', 'bdevselement' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'range' => [
                    'px' => [
                        'min' => -100,
                        'max' => 500,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .slick-dots' => 'bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'dots_nav_spacing',
            [
                'label' => __( 'Spacing', 'bdevselement' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => ['px'],
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li' => 'margin-right: calc({{SIZE}}{{UNIT}} / 2); margin-left: calc({{SIZE}}{{UNIT}} / 2);',
                ],
            ]
        );

        $this->add_responsive_control(
            'dots_nav_align',
            [
                'label' => __( 'Alignment', 'bdevselement' ),
                'type' => Controls_Manager::CHOOSE,
                'label_block' => false,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'bdevselement' ),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'bdevselement' ),
                        'icon' => 'eicon-h-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'bdevselement' ),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'toggle' => true,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots' => 'text-align: {{VALUE}}'
                ]
            ]
        );

        $this->start_controls_tabs( '_tabs_dots' );
        $this->start_controls_tab(
            '_tab_dots_normal',
            [
                'label' => __( 'Normal', 'bdevselement' ),
            ]
        );

        $this->add_control(
            'dots_nav_color',
            [
                'label' => __( 'Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li button:before' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            '_tab_dots_hover',
            [
                'label' => __( 'Hover', 'bdevselement' ),
            ]
        );

        $this->add_control(
            'dots_nav_hover_color',
            [
                'label' => __( 'Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots li button:hover:before' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            '_tab_dots_active',
            [
                'label' => __( 'Active', 'bdevselement' ),
            ]
        );

        $this->add_control(
            'dots_nav_active_color',
            [
                'label' => __( 'Color', 'bdevselement' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .slick-dots .slick-active button:before' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->end_controls_section();
    }

	protected function render() {
        $settings = $this->get_settings_for_display();

        if ( empty( $settings['slides'] ) ) {
            return;
        }

        $title = bdevs_element_kses_basic( $settings['title' ] );
        $this->add_inline_editing_attributes( 'title', 'basic' );
        $this->add_render_attribute( 'title', 'class', 'big_title mb-0' );

        ?>

        <?php if ( $settings['design_style'] == 'style_4' ): ?>
        <section class="testimonial_section sec_ptb_130 bg_gray clearfix">
            <div class="container">
                <?php if ( !empty($settings['title']) ): ?>
                <div class="row justify-content-center">
                    <div class="col-lg-6 col-md-7 col-sm-9">
                        <div class="section_title text-center mb_30 wow fadeInUp2" data-wow-delay=".1s">
                            <?php if ( $settings['sub_title'] ) : ?>
                            <h4 class="small_title"><?php echo bdevs_element_kses_intermediate( $settings['sub_title'] ); ?></h4>
                            <?php endif; ?>
                            <?php printf( '<%1$s %2$s>%3$s</%1$s>',
                                tag_escape( $settings['title_tag'] ),
                                $this->get_render_attribute_string( 'title' ),
                                $title
                            ); ?>
                            <?php if ( $settings['big_title'] ) : ?>
                            <span class="biggest_title"><?php echo bdevs_element_kses_intermediate( $settings['big_title'] ); ?></span>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <?php endif; ?>

                <div class="testimonial_carousel column_3_carousel owl-carousel owl-theme wow fadeInUp2" data-wow-delay=".3s">
                    <?php foreach ( $settings['slides'] as $slide ) :
                    // image 
                    $image = wp_get_attachment_image_url( $slide['image']['id'], $settings['thumbnail_size'] );
                    // bg_image
                    $bg_image = wp_get_attachment_image_url( $slide['bg_image']['id'], 'full' );
                    ?> 
                    <div class="item">
                        <div class="testimonial_primary">
                            <div class="content_wrap">
                                <?php if( !empty($slide['message']) ): ?>
                                <p><?php echo bdevs_element_kses_intermediate( $slide['message'] ); ?></p>
                                <?php endif; ?>
                                <?php if( !empty($bg_image) ): ?>
                                <span class="quote_icon">
                                    <img src="<?php print esc_url($slide['bg_image']['url']); ?>" alt="icon_not_found">
                                </span>
                                <?php endif; ?>
                            </div>
                            <div class="hero_info_wrap">
                                <?php if( !empty($image) ): ?>
                                <div class="hero_thumbnail">
                                    <img src="<?php print esc_url($slide['image']['url']); ?>" alt="icon_not_found">
                                </div>
                                <?php endif; ?>
                                <div class="hero_info">
                                    <?php if ( $slide['client_name'] ): ?> 
                                    <h3 class="hero_name"><?php echo bdevs_element_kses_basic( $slide['client_name'] ); ?></h3>
                                    <?php endif; ?>
                                    <?php if ( $slide['designation_name'] ): ?>
                                    <span class="hero_title"><?php echo bdevs_element_kses_basic( $slide['designation_name'] ); ?></span>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </section>
        <?php elseif ( $settings['design_style'] == 'style_3' ): ?>
        <section class="testimonial_section bg_gray clearfix position-relative">
            <?php if( !empty($settings['default_image']['id']) ): ?>
            <div class="testimonial_image image-50 image-right-50" style="background-image: url(<?php echo $settings['default_image']['url']; ?>);"></div>
            <?php endif; ?>
            <div class="container-fluid">
                <div class="row no-gutters">
                    <div class="col-lg-6 col-md-10 col-sm-12 col-xs-12">
                        <div class="testimonial_auto_wrap">
                            <?php if ( !empty($settings['title']) ) : ?>
                            <div class="section_title mb_30 wow fadeInUp2" data-wow-delay=".2s">
                                <?php if ( $settings['sub_title'] ) : ?>
                                <h4 class="small_title"><?php echo bdevs_element_kses_intermediate( $settings['sub_title'] ); ?></h4>
                                <?php endif; ?>
                                <?php printf( '<%1$s %2$s>%3$s</%1$s>',
                                    tag_escape( $settings['title_tag'] ),
                                    $this->get_render_attribute_string( 'title' ),
                                    $title
                                ); ?>
                                <?php if ( $settings['big_title'] ) : ?>
                                <span class="biggest_title"><?php echo bdevs_element_kses_intermediate( $settings['big_title'] ); ?></span>
                                <?php endif; ?>
                            </div>
                            <?php endif; ?>

                            <div class="testimonial_carousel column_1_carousel owl-carousel owl-theme wow fadeInUp2" data-wow-delay=".3s">
                                <?php foreach ( $settings['slides'] as $slide ) :
                                // image 
                                $image = wp_get_attachment_image_url( $slide['image']['id'], $settings['thumbnail_size'] );
                                // bg_image
                                $bg_image = wp_get_attachment_image_url( $slide['bg_image']['id'], 'full' );
                                ?> 
                                <div class="item">
                                    <div class="testimonial_primary">
                                        <div class="content_wrap">
                                            <?php if( !empty($slide['message']) ): ?>
                                            <p class="font_24"><?php echo bdevs_element_kses_intermediate( $slide['message'] ); ?></p>
                                            <?php endif; ?>
                                            <?php if( !empty($bg_image) ): ?>
                                            <span class="quote_icon">
                                                <img src="<?php print esc_url($slide['bg_image']['url']); ?>" alt="icon_not_found">
                                            </span>
                                            <?php endif; ?>
                                        </div>
                                        <div class="hero_info_wrap">
                                            <?php if( !empty($image) ): ?>
                                            <div class="hero_thumbnail">
                                                <img src="<?php print esc_url($slide['image']['url']); ?>" alt="icon_not_found">
                                            </div>
                                            <?php endif; ?>
                                            <div class="hero_info">
                                                <?php if ( $slide['client_name'] ): ?> 
                                                <h3 class="hero_name"><?php echo bdevs_element_kses_basic( $slide['client_name'] ); ?></h3>
                                                <?php endif; ?>
                                                <?php if ( $slide['designation_name'] ): ?>
                                                <span class="hero_title"><?php echo bdevs_element_kses_basic( $slide['designation_name'] ); ?></span>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>

                </div>
            </div>
        </section>
        <?php elseif ( $settings['design_style'] == 'style_2' ): 
        ?>

        <section class="testimonial_section sec_ptb_130 clearfix">
            <div class="container position-relative">
                <?php if ( !empty($settings['title']) ) : ?>
                <div class="row justify-content-lg-start">
                    <div class="col-lg-6 col-md-7 col-sm-9 col-xs-12">
                        <div class="section_title mb_80 wow fadeInUp2" data-wow-delay=".1s">
                            <?php if ( $settings['sub_title'] ) : ?>
                            <h4 class="small_title"><?php echo bdevs_element_kses_intermediate( $settings['sub_title'] ); ?></h4>
                            <?php endif; ?>
                            <?php printf( '<%1$s %2$s>%3$s</%1$s>',
                                tag_escape( $settings['title_tag'] ),
                                $this->get_render_attribute_string( 'title' ),
                                $title
                            ); ?>
                            <?php if ( $settings['big_title'] ) : ?>
                            <span class="biggest_title"><?php echo bdevs_element_kses_intermediate( $settings['big_title'] ); ?></span>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <?php endif; ?>

                <div class="row justify-content-lg-between">
                    <div class="col-lg-4 col-md-12 col-sm-12 col-xs-12 order-last">
                        <?php if( !empty($settings['default_image']['id']) ): ?>
                        <div class="testimonial_person_image wow fadeInUp2" data-wow-delay=".3s">
                            <img src="<?php echo $settings['default_image']['url']; ?>" alt="image_not_found" />
                        </div>
                        <?php endif; ?>
                    </div>

                    <div class="col-lg-8 col-md-12 col-sm-12 col-xs-12">
                        <div class="creative_testimonial_carousel owl-carousel owl-theme wow fadeInUp2" data-wow-delay=".5s">
                            <?php foreach ( $settings['slides'] as $slide ) :
                            // image 
                            $image = wp_get_attachment_image_url( $slide['image']['id'], $settings['thumbnail_size'] );
                            // bg_image
                            $bg_image = wp_get_attachment_image_url( $slide['bg_image']['id'], 'full' );
                            ?> 
                            <div class="item">
                                <div class="testimonial_primary">
                                    <div class="content_wrap">
                                        <?php if( !empty($slide['message']) ): ?>
                                        <p><?php echo bdevs_element_kses_intermediate( $slide['message'] ); ?></p>
                                        <?php endif; ?>
                                        <?php if( !empty($bg_image) ): ?>
                                        <span class="quote_icon">
                                            <img src="<?php print esc_url($slide['bg_image']['url']); ?>" alt="icon_not_found">
                                        </span>
                                        <?php endif; ?>
                                    </div>
                                    <div class="hero_info_wrap">
                                        <?php if( !empty($image) ): ?>
                                        <div class="hero_thumbnail">
                                            <img src="<?php print esc_url($slide['image']['url']); ?>" alt="icon_not_found">
                                        </div>
                                        <?php endif; ?>
                                        <div class="hero_info">
                                            <?php if ( $slide['client_name'] ): ?> 
                                            <h3 class="hero_name"><?php echo bdevs_element_kses_basic( $slide['client_name'] ); ?></h3>
                                            <?php endif; ?>
                                            <?php if ( $slide['designation_name'] ): ?>
                                            <span class="hero_title"><?php echo bdevs_element_kses_basic( $slide['designation_name'] ); ?></span>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>

                <div class="orange_shape wow fadeInUp2" data-wow-delay=".1s"></div>

            </div>
        </section>


        <?php else: ?>

        <section class="testimonial_section sec_ptb_130 bg_gray clearfix">
            <div class="container">
                <?php if ( !empty($settings['title']) ) : ?>
                <div class="row justify-content-lg-start">
                    <div class="col-lg-8 col-md-8 col-sm-10 col-xs-12">
                        <div class="section_title mb_30 wow fadeInUp2" data-wow-delay=".1s">
                            <?php if ( $settings['sub_title'] ) : ?>
                                <h4 class="small_title"><?php echo bdevs_element_kses_intermediate( $settings['sub_title'] ); ?></h4>
                            <?php endif; ?>

                            <?php printf( '<%1$s %2$s>%3$s</%1$s>',
                                tag_escape( $settings['title_tag'] ),
                                $this->get_render_attribute_string( 'title' ),
                                $title
                            ); ?>
                            <?php if ( $settings['sub_title'] ) : ?>
                            <span class="biggest_title"><?php echo bdevs_element_kses_intermediate( $settings['big_title'] ); ?></span>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <?php endif; ?>

                <div class="row justify-content-lg-between">
                    <div class="col-lg-8 col-md-12 col-sm-12 col-xs-12">
                        <div class="testimonial_carousel column_2_carousel owl-carousel owl-theme wow fadeInUp2" data-wow-delay=".3s">
                            <?php foreach ( $settings['slides'] as $slide ) :
                            // image 
                            if ( !empty( $slide['image']['id'] )) {
                                $image = wp_get_attachment_image_url( $slide['image']['id'], $settings['thumbnail_size'] );
                            }
                            if ( !empty( $slide['bg_image']['id'] )) {
                                $bg_image = wp_get_attachment_image_url( $slide['bg_image']['id'], 'full' );
                            }
                            
                            // bg_image
                            
                            ?> 
                            <div class="item">
                                <div class="testimonial_primary">
                                    <div class="content_wrap">
                                        <?php if ( $slide['message'] ): ?>
                                        <p><?php echo bdevs_element_kses_basic( $slide['message'] ); ?></p>
                                        <?php endif; ?>
                                        <?php if( !empty($bg_image) ): ?>
                                        <span class="quote_icon">
                                            <img src="<?php print esc_url($slide['bg_image']['url']); ?>" alt="icon_not_found">
                                        </span>
                                        <?php endif; ?>
                                    </div>
                                    <div class="hero_info_wrap">
                                        <?php if( !empty($image) ): ?>
                                        <div class="hero_thumbnail">
                                            <img src="<?php print esc_url($slide['image']['url']); ?>" alt="icon_not_found">
                                        </div>
                                        <?php endif; ?>
                                        <div class="hero_info">
                                            <?php if ( $slide['client_name'] ): ?> 
                                            <h3 class="hero_name"><?php echo bdevs_element_kses_basic( $slide['client_name'] ); ?></h3>
                                            <?php endif; ?>
                                            <?php if ( $slide['designation_name'] ): ?>
                                            <span class="hero_title"><?php echo bdevs_element_kses_basic( $slide['designation_name'] ); ?></span>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>

                <?php if( $settings['right_img_switch'] == 'yes' ):

                    if ( !empty( $settings['right_image_1']['id'] )) {
                        $right_image_1 = wp_get_attachment_image_url( $settings['right_image_1']['id'], 'full' );
                    }

                    if ( !empty( $settings['right_image_2']['id'] )) {
                        $right_image_2 = wp_get_attachment_image_url( $settings['right_image_2']['id'], 'full' );
                    }

                    if ( !empty( $settings['right_image_3']['id'] )) {
                        $right_image_3 = wp_get_attachment_image_url( $settings['right_image_3']['id'], 'full' );
                    }

                    if ( !empty( $settings['right_image_4']['id'] )) {
                        $right_image_4 = wp_get_attachment_image_url( $settings['right_image_4']['id'], 'full' );
                    }

                    if ( !empty( $settings['right_image_5']['id'] )) {
                        $right_image_5 = wp_get_attachment_image_url( $settings['right_image_5']['id'], 'full' );
                    }

                    if ( !empty( $settings['right_image_6']['id'] )) {
                        $right_image_6 = wp_get_attachment_image_url( $settings['right_image_6']['id'], 'full' );
                    }
                    
                    ?>
                <div class="decoration_images_1">
                    <?php if (!empty( $right_image_1 )) :?>
                    <div class="deco_image deco_image_1 wow fadeInUp2" data-wow-delay=".1s">
                        <img src="<?php print esc_url($right_image_1); ?>" alt="image_not_found">
                    </div>
                    <?php endif; ?>
                    <?php if (!empty( $right_image_2 )) :?>
                    <div class="deco_image deco_image_2 wow fadeInUp2" data-wow-delay=".2s">
                        <img src="<?php print esc_url($right_image_2); ?>" alt="image_not_found">
                    </div>
                    <?php endif; ?>
                    <?php if (!empty( $right_image_3 )) :?>
                    <div class="deco_image deco_image_3 wow fadeInUp2" data-wow-delay=".3s">
                        <img src="<?php print esc_url($right_image_3); ?>" alt="image_not_found">
                    </div>
                    <?php endif; ?>
                    <?php if (!empty( $right_image_4 )) :?>
                    <div class="deco_image deco_image_4 wow fadeInUp2" data-wow-delay=".4s">
                        <img src="<?php print esc_url($right_image_4); ?>" alt="image_not_found">
                    </div>
                    <?php endif; ?>
                    <?php if (!empty( $right_image_5 )) :?>
                    <div class="deco_image shape_image_1 wow fadeInUp2" data-wow-delay=".2s">
                        <img src="<?php print esc_url($right_image_5); ?>" alt="image_not_found">
                    </div>
                    <?php endif; ?>
                    <?php if (!empty( $right_image_6 )) :?>
                    <div class="deco_image shape_image_2 wow fadeInUp2" data-wow-delay=".3s">
                        <img src="<?php print esc_url($right_image_6); ?>" alt="image_not_found">
                    </div>
                    <?php endif; ?>
                </div>
                <?php endif; ?>

            </div>
        </section>

        <?php endif; ?>
        <?php
    }
}
