<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package frintem
 */

/**
 *
 * frintem header
 */

function frintem_check_header()
{
    $frintem_header_style = function_exists('get_field') ? get_field('header_style') : NULL;
    $frintem_default_header_style = get_theme_mod('choose_default_header', __('header-style-1', 'frintem'));

    if ($frintem_header_style == 'header-style-1') {
        frintem_header_style_1();
    } elseif ($frintem_header_style == 'header-style-2') {
        frintem_header_style_2();
    } elseif ($frintem_header_style == 'header-style-3') {
        frintem_header_style_3();
    } elseif ($frintem_header_style == 'header-style-4') {
        frintem_header_style_4();
    } elseif ($frintem_header_style == 'header-style-5') {
        frintem_header_style_5();
    } else {

        /** default header style **/
        if ($frintem_default_header_style == 'header-style-2') {
            frintem_header_style_2();
        } elseif ($frintem_default_header_style == 'header-style-3') {
            frintem_header_style_3();
        } elseif ($frintem_default_header_style == 'header-style-4') {
            frintem_header_style_4();
        } elseif ($frintem_default_header_style == 'header-style-5') {
            frintem_header_style_5();
        } else {
            frintem_header_style_1();
        }
    }

}

add_action('frintem_header_style', 'frintem_check_header', 10);

/**
 * header style 1 + default
 */

function frintem_header_style_1()
{
    // top info
    $frintem_mail_id = get_theme_mod('frintem_mail_id', __('info@example.com', 'frintem'));
    $frintem_time = get_theme_mod('frintem_time', __('Sun - Monday, 09 am - 04 pm', 'frintem'));
    $frintem_address = get_theme_mod('frintem_address', __('20 Main Street, USA', 'frintem'));

    $frintem_topbar_switch = get_theme_mod('frintem_topbar_switch', false);
    $frintem_cart_hide = get_theme_mod('frintem_cart_hide', false);
    $frintem_show_button = get_theme_mod('frintem_show_button', false);
    $frintem_show_cta = get_theme_mod('frintem_show_cta', false);
    $frintem_hamburger_hide = get_theme_mod('frintem_hamburger_hide', false);
    $frintem_show_button = get_theme_mod('frintem_show_button', false);
    $frintem_header_right = get_theme_mod('frintem_header_right', false);
    $frintem_show_header_search = get_theme_mod('frintem_show_header_search', false);
    $frintem_show_header_side = get_theme_mod('frintem_show_header_side', false);
    $frintem_sticky_header = get_theme_mod('frintem_sticky_header', false);

    $sticky_class = "";
    if($frintem_sticky_header == true){
        $sticky_class = "sticky_header";
    }

    $frintem_menu_col = $frintem_header_right ? 'col-lg-6' : 'col-lg-9';

    if (rtl_enable()) {
        $btn_text = get_theme_mod('frintem_button_text_rtl', __('Get A Quote', 'frintem'));
    } else {
        $btn_text = get_theme_mod('frintem_button_text', __('Get A Quote', 'frintem'));
    }

    $btn_link = get_theme_mod('frintem_button_link', __('#', 'frintem'));

    ?>

    <!-- header begin -->
    <header class="header_section header_default clearfix header_section_5 <?php print esc_attr($sticky_class); ?>">
        <?php if (!empty($frintem_topbar_switch)): ?>
            <div class="header_top bg_light clearfix">
                <div class="maxw_1420 container">
                    <div class="row align-items-center">
                        <div class="col-lg-8">
                            <ul class="header_contact_info ul_li clearfix">
                                <?php if (!empty($frintem_address)): ?>
                                    <li><i class="far fa-map-marker-alt"></i><?php print esc_html($frintem_address); ?>
                                    </li>
                                <?php endif; ?>
                                <?php if (!empty($frintem_mail_id)): ?>
                                    <li><i class="far fa-envelope-open"></i> <?php print esc_html($frintem_mail_id); ?>
                                    </li>
                                <?php endif; ?>
                                <?php if (!empty($frintem_time)): ?>
                                    <li><i class="far fa-clock"></i> <?php print esc_html($frintem_time); ?></li>
                                <?php endif; ?>
                            </ul>
                        </div>

                        <div class="col-lg-4">
                            <ul class="header_items_list ul_li_right clearfix">
                                <li>
                                    <ul class="primary_social_links ul_li clearfix">
                                        <?php frintem_header_social_profiles(); ?>
                                    </ul>
                                </li>
                                <li>
                                    <div class="select_option mb-0">
                                        <?php frintem_header_lang_defualt(); ?>
                                    </div>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div class="header_bottom bg_default_blue">
            <div class="maxw_1420 container">
                <div class="row align-items-center">

                    <div class="col-lg-3">
                        <div class="brand_logo">
                            <?php frintem_header_logo(); ?>

                            <ul class="mobilemenu_btns_group ul_li_right clearfix">
                                <li>
                                    <button type="button" class="search_btn" data-toggle="collapse"
                                            data-target="#search_body_collapse" aria-expanded="false"
                                            aria-controls="search_body_collapse">
                                        <i class="fal fa-search"></i>
                                    </button>
                                </li>
                                <li>
                                    <button type="button" class="mobile_menu_btn"><i class="fal fa-bars"></i></button>
                                </li>
                            </ul>
                        </div>
                    </div>

                    <div class="<?php print esc_attr($frintem_menu_col); ?>">
                        <nav class="main_menu clearfix">
                            <?php frintem_header_menu(); ?>
                        </nav>
                    </div>

                    <?php if (!empty($frintem_header_right)): ?>
                        <div class="col-lg-3">
                            <ul class="header_btns_group ul_li_right clearfix">
                                <?php if (!empty($frintem_show_header_search)): ?>
                                    <li>
                                        <button type="button" class="action_btn search_btn bg_default_purple"
                                                data-toggle="collapse" data-target="#search_body_collapse"
                                                aria-expanded="false" aria-controls="search_body_collapse">
                                            <i class="fal fa-search"></i>
                                        </button>
                                    </li>
                                <?php endif; ?>

                                <?php if (!empty($frintem_show_button)): ?>
                                    <li>
                                        <a class="custom_btn bg_default_yellow"
                                           href="<?php print esc_url($btn_link); ?>">
                                            <?php print esc_html($btn_text); ?>
                                            <span><i class="fal fa-arrow-right"></i></span>
                                        </a>
                                    </li>
                                <?php endif; ?>
                            </ul>
                        </div>
                    <?php endif; ?>

                </div>
            </div>
        </div>

        <div id="search_body_collapse" class="search_body_collapse collapse">
            <div class="search_body">
                <div class="container maxw_1420">
                    <form action="#">
                        <div class="form_item m-0">
                            <input type="search" name="search" placeholder="Type here...">
                            <button type="submit"><i class="fal fa-search"></i></button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </header>

    <!-- header end -->

    <!-- slide-bar start -->
    <aside class="slide-bar">
        <div class="close-mobile-menu">
            <a href="javascript:void(0);"><i class="fas fa-times"></i></a>
        </div>

        <nav class="side-mobile-menu">
            <?php frintem_mobile_menu(); ?>
        </nav>
    </aside>
    <div class="body-overlay"></div>
    <!-- slide-bar end -->


    <?php
}

/**
 * header style 2
 */
function frintem_header_style_2()
{
    $frintem_contact_label = get_theme_mod('frintem_contact_label', __('contact us', 'frintem'));
    $frintem_phone = get_theme_mod('frintem_phone', __('+012 (895) 632 89', 'frintem'));
    $frintem_topbar_switch = get_theme_mod('frintem_topbar_switch', false);
    $frintem_cart_hide = get_theme_mod('frintem_cart_hide', false);
    $frintem_show_button = get_theme_mod('frintem_show_button', false);
    $frintem_header_right = get_theme_mod('frintem_header_right', false);
    $frintem_show_header_search = get_theme_mod('frintem_show_header_search', false);
    $frintem_show_header_side = get_theme_mod('frintem_show_header_side', false);
    $frintem_sticky_header = get_theme_mod('frintem_sticky_header', false);

    $sticky_class = "";
    if($frintem_sticky_header == true){
        $sticky_class = "sticky_header";
    }
    $frintem_header_right = get_theme_mod('frintem_header_right', true);

    if (rtl_enable()) {
        $btn_text = get_theme_mod('frintem_button_text_rtl', __('Get A Quote', 'frintem'));
    } else {
        $btn_text = get_theme_mod('frintem_button_text', __('Get A Quote', 'frintem'));
    }

    $btn_link = get_theme_mod('frintem_button_link', __('#', 'frintem'));

    ?>

    <header class="header_section primary_header clearfix <?php print esc_attr($sticky_class); ?>">
        <div class="primary_header_content clearfix">
            <div class="brand_logo">
                <?php frintem_header_logo(); ?>
                <ul class="mobilemenu_btns_group ul_li_right clearfix">
                    <li>
                        <button type="button" class="search_btn" data-toggle="collapse"
                                data-target="#search_body_collapse" aria-expanded="false"
                                aria-controls="search_body_collapse">
                            <i class="fal fa-search"></i>
                        </button>
                    </li>
                    <li>
                        <button type="button" class="mobile_menu_btn"><i class="fal fa-bars"></i></button>
                    </li>
                </ul>
            </div>

            <nav class="main_menu clearfix">
                <?php frintem_header_menu(); ?>
            </nav>

            <div class="header_hotline bg_gray clearfix">
                <div class="item_icon">
                    <img src="<?php echo get_template_directory_uri(); ?>/assets/images/icons/hot_line.png"
                         alt="icon_not_found">
                </div>
                <div class="item_content">
                    <?php if (!empty($frintem_contact_label)): ?>
                        <h4> <?php print esc_html($frintem_contact_label); ?></h4>
                    <?php endif; ?>
                    <?php if (!empty($frintem_phone)): ?>
                        <span> <?php print esc_html($frintem_phone); ?></span>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <div id="search_body_collapse" class="search_body_collapse collapse">
            <div class="search_body">
                <div class="container-fluid">
                    <form method="get" action="<?php print esc_url(home_url('/')); ?>">
                        <div class="form_item m-0">
                            <input name="s" type="search" value="<?php print esc_attr(get_search_query()) ?>"
                                   placeholder="<?php print esc_attr__('Type Here...', 'frintem'); ?>">
                            <button type="submit"><i class="fal fa-search"></i></button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </header>

    <!-- slide-bar start -->
    <aside class="slide-bar">
        <div class="close-mobile-menu">
            <a href="javascript:void(0);"><i class="fas fa-times"></i></a>
        </div>

        <nav class="side-mobile-menu">
            <?php frintem_mobile_menu(); ?>
        </nav>
    </aside>
    <div class="body-overlay"></div>
    <!-- slide-bar end -->

    <?php
}

/**
 * header style 3
 */
function frintem_header_style_3()
{
    // top left
    $frintem_social_label = get_theme_mod('frintem_social_label', __('Social Links:', 'frintem'));
    $frintem_mail_id = get_theme_mod('frintem_mail_id', __('info@example.com', 'frintem'));
    $frintem_time = get_theme_mod('frintem_time', __('Sun - Monday, 09 am - 04 pm', 'frintem'));
    $frintem_address = get_theme_mod('frintem_address', __('20 Main Street, USA', 'frintem'));
    $frintem_topbar_switch = get_theme_mod('frintem_topbar_switch', false);
    $frintem_show_header_side = get_theme_mod('frintem_show_header_side', false);
    $frintem_sticky_header = get_theme_mod('frintem_sticky_header', false);

    $sticky_class = "";
    if($frintem_sticky_header == true){
        $sticky_class = "sticky_header";
    }

    $frintem_show_button = get_theme_mod('frintem_show_button', false);
    $frintem_header_right = get_theme_mod('frintem_header_right', false);
    $frintem_show_header_search = get_theme_mod('frintem_show_header_search', false);


    if (rtl_enable()) {
        $btn_text = get_theme_mod('frintem_button_text_rtl', __('Get A Quote', 'frintem'));
    } else {
        $btn_text = get_theme_mod('frintem_button_text', __('Get A Quote', 'frintem'));
    }

    $btn_link = get_theme_mod('frintem_button_link', __('#', 'frintem'));

    // social 
    $frintem_topbar_fb_url = get_theme_mod('frintem_topbar_fb_url', __('#', 'frintem'));
    $frintem_topbar_twitter_url = get_theme_mod('frintem_topbar_twitter_url', __('#', 'frintem'));
    $frintem_topbar_instagram_url = get_theme_mod('frintem_topbar_instagram_url', __('#', 'frintem'));
    $frintem_topbar_linkedin_url = get_theme_mod('frintem_topbar_linkedin_url', __('#', 'frintem'));
    $frintem_topbar_youtube_url = get_theme_mod('frintem_topbar_youtube_url', __('#', 'frintem'));

    ?>

    <header class="header_section transparent_header header_default clearfix <?php print esc_attr($sticky_class); ?>">
        <?php if (!empty($frintem_topbar_switch)): ?>
            <div class="header_top bg_default_blue text-white clearfix">
                <div class="maxw_1420 container">
                    <div class="row align-items-center">
                        <div class="col-lg-8">
                            <ul class="header_contact_info ul_li clearfix">
                                <?php if (!empty($frintem_address)): ?>
                                    <li><i class="far fa-map-marker-alt"></i><?php print esc_html($frintem_address); ?>
                                    </li>
                                <?php endif; ?>
                                <?php if (!empty($frintem_mail_id)): ?>
                                    <li><i class="far fa-envelope-open"></i> <?php print esc_html($frintem_mail_id); ?>
                                    </li>
                                <?php endif; ?>
                                <?php if (!empty($frintem_time)): ?>
                                    <li><i class="far fa-clock"></i> <?php print esc_html($frintem_time); ?></li>
                                <?php endif; ?>
                            </ul>
                        </div>

                        <div class="col-lg-4">
                            <ul class="header_items_list ul_li_right clearfix">
                                <li>
                                    <div class="header_social_links d-flex align-items-center">
                                        <span class="social_title text-white"><?php print esc_html($frintem_social_label); ?></span>
                                        <ul class="primary_social_links ul_li clearfix">
                                            <?php frintem_header_social_profiles(); ?>
                                        </ul>
                                    </div>
                                </li>
                                <li>
                                    <div class="select_option mb-0">
                                        <?php frintem_header_lang_defualt(); ?>
                                    </div>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>

        <div class="header_bottom">
            <div class="maxw_1420 container">
                <div class="row align-items-center">

                    <div class="col-lg-3">
                        <div class="brand_logo">
                            <?php frintem_header_logo(); ?>

                            <ul class="mobilemenu_btns_group ul_li_right clearfix">
                                <li>
                                    <button type="button" class="search_btn" data-toggle="collapse"
                                            data-target="#search_body_collapse" aria-expanded="false"
                                            aria-controls="search_body_collapse">
                                        <i class="fal fa-search"></i>
                                    </button>
                                </li>
                                <li>
                                    <button type="button" class="mobile_menu_btn"><i class="fal fa-bars"></i></button>
                                </li>
                            </ul>
                        </div>
                    </div>

                    <div class="col-lg-6">
                        <nav class="main_menu clearfix">
                            <?php frintem_header_menu(); ?>
                        </nav>
                    </div>

                    <div class="col-lg-3">
                        <?php if (!empty($frintem_header_right)): ?>
                        <ul class="header_btns_group ul_li_right clearfix">
                            <?php if (!empty($frintem_show_header_search)): ?>
                                <li>
                                    <button type="button" class="action_btn search_btn bg_default_purple"
                                            data-toggle="collapse" data-target="#search_body_collapse"
                                            aria-expanded="false" aria-controls="search_body_collapse">
                                        <i class="fal fa-search"></i>
                                    </button>
                                </li>
                            <?php endif; ?>
                            <?php if (!empty($frintem_show_button)): ?>
                                <li>
                                    <a class="custom_btn bg_default_yellow" href="<?php print esc_url($btn_link); ?>">
                                        <?php print esc_html($btn_text); ?>
                                        <span><i class="fal fa-arrow-right"></i></span>
                                    </a>
                                </li>
                            <?php endif; ?>
                        </ul>
                        <?php endif; ?>
                    </div>

                </div>
            </div>
        </div>

        <div id="search_body_collapse" class="search_body_collapse collapse">
            <div class="search_body">
                <div class="container maxw_1420">
                    <form method="get" action="<?php print esc_url(home_url('/')); ?>">
                        <div class="form_item m-0">
                            <input name="s" type="search" value="<?php print esc_attr(get_search_query()) ?>"
                                   placeholder="<?php print esc_attr__('Type Here...', 'frintem'); ?>">
                            <button type="submit"><i class="fal fa-search"></i></button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </header>

    <!-- slide-bar start -->
    <aside class="slide-bar">
        <div class="close-mobile-menu">
            <a href="javascript:void(0);"><i class="fas fa-times"></i></a>
        </div>

        <nav class="side-mobile-menu">
            <?php frintem_mobile_menu(); ?>
        </nav>
    </aside>
    <div class="body-overlay"></div>
    <!-- slide-bar end -->

    <?php
}

/**
 * header style 3
 */
function frintem_header_style_4()
{
    // top left
    $frintem_mail_id = get_theme_mod('frintem_mail_id', __('info@example.com', 'frintem'));
    $frintem_time = get_theme_mod('frintem_time', __('Sun - Monday, 09 am - 04 pm', 'frintem'));
    $frintem_address = get_theme_mod('frintem_address', __('20 Main Street, USA', 'frintem'));
    $frintem_topbar_switch = get_theme_mod('frintem_topbar_switch', false);
    $frintem_show_button = get_theme_mod('frintem_show_button', true);
    $frintem_cart_hide = get_theme_mod('frintem_cart_hide', false);
    $frintem_show_button = get_theme_mod('frintem_show_button', false);
    $frintem_header_right = get_theme_mod('frintem_header_right', false);
    $frintem_show_header_search = get_theme_mod('frintem_show_header_search', false);

    $frintem_show_header_side = get_theme_mod('frintem_show_header_side', false);

    $frintem_sticky_header = get_theme_mod('frintem_sticky_header', false);


    $sticky_class = "";
    if($frintem_sticky_header == true){
        $sticky_class = "sticky_header";
    }

    if (rtl_enable()) {
        $btn_text = get_theme_mod('frintem_button_text_rtl', __('Get A Quote', 'frintem'));
    } else {
        $btn_text = get_theme_mod('frintem_button_text', __('Get A Quote', 'frintem'));
    }

    $btn_link = get_theme_mod('frintem_button_link', __('#', 'frintem'));

    // social 
    $frintem_topbar_fb_url = get_theme_mod('frintem_topbar_fb_url', __('#', 'frintem'));
    $frintem_topbar_twitter_url = get_theme_mod('frintem_topbar_twitter_url', __('#', 'frintem'));
    $frintem_topbar_instagram_url = get_theme_mod('frintem_topbar_instagram_url', __('#', 'frintem'));
    $frintem_topbar_linkedin_url = get_theme_mod('frintem_topbar_linkedin_url', __('#', 'frintem'));
    $frintem_topbar_youtube_url = get_theme_mod('frintem_topbar_youtube_url', __('#', 'frintem'));

    ?>

    <header class="header_section secondary_header clearfix <?php print esc_attr($sticky_class); ?>">
        <?php if (!empty($frintem_topbar_switch)): ?>
            <div class="header_top bg_light clearfix">
                <div class="maxw_1420 container">
                    <div class="row align-items-center">
                        <div class="col-lg-6">
                            <ul class="header_contact_info ul_li clearfix">
                                <?php if (!empty($frintem_address)): ?>
                                    <li><i class="far fa-map-marker-alt"></i><?php print esc_html($frintem_address); ?>
                                    </li>
                                <?php endif; ?>
                                <?php if (!empty($frintem_mail_id)): ?>
                                    <li><i class="far fa-envelope-open"></i> <?php print esc_html($frintem_mail_id); ?>
                                    </li>
                                <?php endif; ?>
                            </ul>
                        </div>

                        <div class="col-lg-6">
                            <ul class="header_items_list ul_li_right clearfix">
                                <?php if (!empty($frintem_time)): ?>
                                    <li>
                                        <ul class="header_contact_info ul_li clearfix">
                                            <li><i class="far fa-clock"></i> <?php print esc_html($frintem_time); ?>
                                            </li>
                                        </ul>
                                    </li>
                                <?php endif; ?>
                                <li>
                                    <div class="select_option mb-0">
                                        <?php frintem_header_lang_defualt(); ?>
                                    </div>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>

        <div class="header_bottom">
            <div class="maxw_1420 container">
                <div class="row align-items-center">

                    <div class="col-lg-3">
                        <div class="brand_logo">
                            <?php frintem_header_logo(); ?>

                            <ul class="mobilemenu_btns_group ul_li_right clearfix">

                                <li>
                                    <button type="button" class="search_btn" data-toggle="collapse"
                                            data-target="#search_body_collapse" aria-expanded="false"
                                            aria-controls="search_body_collapse">
                                        <i class="fal fa-search"></i>
                                    </button>
                                </li>

                                <?php if (!empty($frintem_cart_hide)): ?>
                                <li>
                                    <button type="button" class="cart_btn">
                                        <i class="fal fa-shopping-cart"></i>
                                        <small class="cart_counter">2</small>
                                    </button>
                                </li>
                                <?php endif; ?>
                                <?php if (!empty($frintem_show_header_side)): ?>
                                <li>
                                    <button type="button" class="mobile_menu_btn"><i class="fal fa-bars"></i></button>
                                </li>
                                 <?php endif; ?>
                            </ul>
                        </div>
                    </div>

                    <div class="col-lg-6">
                        <nav class="main_menu clearfix">
                            <?php frintem_header_menu(); ?>
                        </nav>
                    </div>

                    <div class="col-lg-3">
                        <?php if (!empty($frintem_header_right)): ?>
                        <ul class="header_icon_btns ul_li_right clearfix">
                            <?php if (!empty($frintem_show_header_search)): ?>
                                <li>
                                    <button type="button" class="search_btn" data-toggle="collapse"
                                            data-target="#search_body_collapse" aria-expanded="false"
                                            aria-controls="search_body_collapse">
                                        <i class="fal fa-search"></i>
                                    </button>
                                </li>
                            <?php endif; ?>
                            <?php if (!empty($frintem_cart_hide)): ?>
                                <li>
                                    <button type="button" class="cart_btn">
                                        <i class="fal fa-shopping-cart"></i>
                                        <small class="cart_counter"><?php echo esc_html(WC()->cart->cart_contents_count); ?></small>
                                    </button>
                                </li>
                            <?php endif; ?>
                            <?php if (!empty($frintem_show_header_side)): ?>
                                <li>
                                    <button type="button" class="mobile_menu_btn">
                                        <img src="<?php echo get_template_directory_uri(); ?>/assets/images/icons/bar_dot_2x.png"
                                             alt="logo_not_found">
                                    </button>
                                </li>
                            <?php endif; ?>
                        </ul>
                        <?php endif; ?>
                    </div>

                </div>
            </div>
        </div>

        <div id="search_body_collapse" class="search_body_collapse collapse">
            <div class="search_body">
                <div class="container maxw_1420">
                    <form method="get" action="<?php print esc_url(home_url('/')); ?>">
                        <div class="form_item m-0">
                            <input name="s" type="search" value="<?php print esc_attr(get_search_query()) ?>"
                                   placeholder="<?php print esc_attr__('Type Here...', 'frintem'); ?>">
                            <button type="submit"><i class="fal fa-search"></i></button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </header>

    <!-- slide-bar start -->
    <aside class="slide-bar">
        <div class="close-mobile-menu">
            <a href="javascript:void(0);"><i class="fas fa-times"></i></a>
        </div>

        <nav class="side-mobile-menu">
            <?php frintem_mobile_menu(); ?>
        </nav>
    </aside>
    <div class="body-overlay"></div>
    <!-- slide-bar end -->

    <?php
}

/**
 * header style 5
 */

function frintem_header_style_5()
{
    // top info
    $frintem_mail_id = get_theme_mod('frintem_mail_id', __('info@example.com', 'frintem'));
    $frintem_time = get_theme_mod('frintem_time', __('Sun - Monday, 09 am - 04 pm', 'frintem'));
    $frintem_address = get_theme_mod('frintem_address', __('20 Main Street, USA', 'frintem'));

    $frintem_topbar_switch = get_theme_mod('frintem_topbar_switch', false);
    $frintem_cart_hide = get_theme_mod('frintem_cart_hide', false);
    $frintem_show_button = get_theme_mod('frintem_show_button', false);
    $frintem_show_cta = get_theme_mod('frintem_show_cta', false);
    $frintem_hamburger_hide = get_theme_mod('frintem_hamburger_hide', false);
    $frintem_show_button = get_theme_mod('frintem_show_button', false);
    $frintem_header_right = get_theme_mod('frintem_header_right', false);
    $frintem_show_header_search = get_theme_mod('frintem_show_header_search', false);

    $frintem_show_header_side = get_theme_mod('frintem_show_header_side', false);

    $frintem_sticky_header = get_theme_mod('frintem_sticky_header', false);

    $sticky_class = "";
    if($frintem_sticky_header == true){
        $sticky_class = "sticky_header";
    }


    $frintem_menu_col = $frintem_header_right ? 'col-lg-6' : 'col-lg-9';

    if (rtl_enable()) {
        $btn_text = get_theme_mod('frintem_button_text_rtl', __('Get A Quote', 'frintem'));
    } else {
        $btn_text = get_theme_mod('frintem_button_text', __('Get A Quote', 'frintem'));
    }

    $btn_link = get_theme_mod('frintem_button_link', __('#', 'frintem'));

    ?>

    <!-- header begin -->
    <header class="header_section header_default clearfix header_section_5 <?php print esc_attr($sticky_class); ?>">
        <?php if (!empty($frintem_topbar_switch)): ?>
            <div class="header_top bg_light clearfix">
                <div class="maxw_1420 container">
                    <div class="row align-items-center">
                        <div class="col-lg-8">
                            <ul class="header_contact_info ul_li clearfix">
                                <?php if (!empty($frintem_address)): ?>
                                    <li><i class="far fa-map-marker-alt"></i><?php print esc_html($frintem_address); ?>
                                    </li>
                                <?php endif; ?>
                                <?php if (!empty($frintem_mail_id)): ?>
                                    <li><i class="far fa-envelope-open"></i> <?php print esc_html($frintem_mail_id); ?>
                                    </li>
                                <?php endif; ?>
                                <?php if (!empty($frintem_time)): ?>
                                    <li><i class="far fa-clock"></i> <?php print esc_html($frintem_time); ?></li>
                                <?php endif; ?>
                            </ul>
                        </div>

                        <div class="col-lg-4">
                            <ul class="header_items_list ul_li_right clearfix">
                                <li>
                                    <ul class="primary_social_links ul_li clearfix">
                                        <?php frintem_header_social_profiles(); ?>
                                    </ul>
                                </li>
                                <li>
                                    <div class="select_option mb-0">
                                        <?php frintem_header_lang_defualt(); ?>
                                    </div>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>
        <div class="header_bottom bg_default_blue">
            <div class="maxw_1420 container">
                <div class="row align-items-center">

                    <div class="col-lg-3">
                        <div class="brand_logo">
                            <?php frintem_header_logo(); ?>

                            <ul class="mobilemenu_btns_group ul_li_right clearfix">
                                <?php if (!empty($frintem_show_header_search)): ?>
                                <li>
                                    <button type="button" class="search_btn" data-toggle="collapse"
                                            data-target="#search_body_collapse" aria-expanded="false"
                                            aria-controls="search_body_collapse">
                                        <i class="fal fa-search"></i>
                                    </button>
                                </li>
                                <?php endif; ?>
                                <?php if (!empty($frintem_show_header_side)): ?>
                                <li>
                                    <button type="button" class="mobile_menu_btn"><i class="fal fa-bars"></i></button>
                                </li>
                                <?php endif; ?>
                            </ul>
                        </div>
                    </div>

                    <div class="<?php print esc_attr($frintem_menu_col); ?>">
                        <nav class="main_menu clearfix">
                            <?php frintem_header_menu(); ?>
                        </nav>
                    </div>

                    <?php if (!empty($frintem_header_right)): ?>
                        <div class="col-lg-3">
                            <ul class="header_btns_group ul_li_right clearfix">
                                <?php if (!empty($frintem_show_header_search)): ?>
                                    <li>
                                        <button type="button" class="action_btn search_btn bg_default_purple"
                                                data-toggle="collapse" data-target="#search_body_collapse"
                                                aria-expanded="false" aria-controls="search_body_collapse">
                                            <i class="fal fa-search"></i>
                                        </button>
                                    </li>
                                <?php endif; ?>

                                <?php if (!empty($frintem_show_button)): ?>
                                    <li>
                                        <a class="custom_btn bg_default_orange"
                                           href="<?php print esc_url($btn_link); ?>">
                                            <?php print esc_html($btn_text); ?>
                                            <span><i class="fal fa-arrow-right"></i></span>
                                        </a>
                                    </li>
                                <?php endif; ?>
                            </ul>
                        </div>
                    <?php endif; ?>

                </div>
            </div>
        </div>

        <div id="search_body_collapse" class="search_body_collapse collapse">
            <div class="search_body">
                <div class="container maxw_1420">
                    <form method="get" action="<?php print esc_url(home_url('/')); ?>">
                        <div class="form_item m-0">
                            <input name="s" type="search" value="<?php print esc_attr(get_search_query()) ?>"
                                   placeholder="<?php print esc_attr__('Type Here...', 'frintem'); ?>">
                            <button type="submit"><i class="fal fa-search"></i></button>
                        </div>
                    </form>
                </div>
            </div>
        </div>
    </header>

    <!-- header end -->

    <!-- slide-bar start -->
    <aside class="slide-bar">
        <div class="close-mobile-menu">
            <a href="javascript:void(0);"><i class="fas fa-times"></i></a>
        </div>

        <nav class="side-mobile-menu">
            <?php frintem_mobile_menu(); ?>
        </nav>
    </aside>
    <div class="body-overlay"></div>
    <!-- slide-bar end -->


    <?php
}


/**
 * [frintem_extra_info description]
 * @return [type] [description]
 */
function frintem_extra_info()
{
    $frintem_extra_info_logo = get_theme_mod('frintem_extra_info_logo', get_template_directory_uri() . '/assets/images/logo/logo-white.png');

    // about title
    $frintem_extra_about_title = get_theme_mod('frintem_extra_about_title', 'About Us');
    $frintem_extra_about_text = get_theme_mod('frintem_extra_about_text', __('We must explain to you how all seds this mistakens idea off denouncing pleasures and praising pain was born and I will give you a completed accounts of the system and expound.', 'frintem'));
    $frintem_extra_button = get_theme_mod('frintem_extra_button', __('CONTACT US', 'frintem'));
    $frintem_extra_button_url = get_theme_mod('frintem_extra_button_url', __('#', 'frintem'));


    // contact title
    $frintem_extra_contact_title = get_theme_mod('frintem_extra_contact_title', __('Contact Info', 'frintem'));

    // address
    $frintem_extra_address = get_theme_mod('frintem_extra_address', __('123/A, Miranda City Likaoli Prikano, Dope United States', 'frintem'));
    $frintem_extra_address_icon = get_theme_mod('frintem_extra_address_icon', __('fal fa-rocket', 'frintem'));

    // phone 
    $frintem_extra_phone = get_theme_mod('frintem_extra_phone', __('+0989 7876 9865 9', 'frintem'));
    $frintem_extra_phone_icon = get_theme_mod('frintem_extra_phone_icon', __('far fa-phone', 'frintem'));

    // email 
    $frintem_extra_email = get_theme_mod('frintem_extra_email', __('info@example.com', 'frintem'));
    $frintem_extra_email_icon = get_theme_mod('frintem_extra_email_icon', __('far fa-envelope-open', 'frintem'));

    ?>

    <!-- extra info start -->
    <div class="extra-info">
        <div class="close-icon menu-close">
            <button>
                <i class="far fa-window-close"></i>
            </button>
        </div>
        <?php if (!empty($frintem_extra_info_logo)) : ?>
            <div class="logo-side mb-30">
                <a class="site-logo-2" href="<?php print home_url(); ?>">
                    <img src="<?php print esc_url($frintem_extra_info_logo); ?>"
                         alt="<?php esc_attr('Logo', 'frintem'); ?>"/>
                </a>
            </div>
        <?php endif; ?>
        <div class="side-info">
            <div class="contact-list mb-40">
                <?php if (!empty($frintem_extra_about_title)) : ?>
                    <h4><?php print esc_html($frintem_extra_about_title); ?></h4>
                <?php endif; ?>

                <?php if (!empty($frintem_extra_about_text)) : ?>
                    <p><?php print esc_html($frintem_extra_about_text); ?></p>
                <?php endif; ?>

                <?php if (!empty($frintem_extra_button)) : ?>
                    <div class="mt-30 mb-30">
                        <a href="<?php print esc_url($frintem_extra_button_url); ?>"
                           class="site-btn white"><?php print esc_html($frintem_extra_button); ?> <span class="icon"><i
                                        class="fal fa-calendar-alt"></i></span> </a>
                    </div>
                <?php endif; ?>

            </div>
            <div class="contact-list mb-40">
                <?php if (!empty($frintem_extra_contact_title)) : ?>
                    <h4><?php print esc_html($frintem_extra_contact_title); ?> </h4>
                <?php endif; ?>

                <?php if (!empty($frintem_extra_address)) : ?>
                    <p>
                        <i class="<?php print esc_attr($frintem_extra_address_icon); ?>"></i>
                        <span><?php print esc_html($frintem_extra_address); ?></span>
                    </p>
                <?php endif; ?>

                <?php if (!empty($frintem_extra_phone)) : ?>
                    <p>
                        <i class="<?php print esc_attr($frintem_extra_phone_icon); ?>"></i>
                        <span><?php print esc_html($frintem_extra_phone); ?></span>
                    </p>
                <?php endif; ?>

                <?php if (!empty($frintem_extra_email)) : ?>
                    <p>
                        <i class="<?php print esc_attr($frintem_extra_email_icon); ?>"></i>
                        <span><?php print esc_html($frintem_extra_email); ?></span>
                    </p>
                <?php endif; ?>
            </div>
        </div>
    </div>
    <div class="offcanvas-overly"></div>
    <!-- extra info end -->


<?php }


// favicon logo
function frintem_favicon_logo_func()
{
    $frintem_favicon = get_template_directory_uri() . '/assets/images/logo/favicon.png';
    $frintem_favicon_url = get_theme_mod('favicon_url', $frintem_favicon);
    ?>

    <link rel="shortcut icon" type="image/x-icon" href="<?php print esc_url($frintem_favicon_url); ?>">

    <?php
}

add_action('wp_head', 'frintem_favicon_logo_func');

// header logo
function frintem_header_logo()
{
    ?>
    <?php
    $frintem_logo_on = function_exists('get_field') ? get_field('is_enable_sec_logo') : NULL;
    $frintem_logo = get_template_directory_uri() . '/assets/images/logo/logo.png';
    $frintem_logo_black = get_template_directory_uri() . '/assets/images/logo/logo-black.png';

    $frintem_site_logo = get_theme_mod('logo', $frintem_logo);
    $frintem_secondary_logo = get_theme_mod('seconday_logo', $frintem_logo_black);
    ?>

    <?php
    if (has_custom_logo()) {
        the_custom_logo();
    } else {

        if (!empty($frintem_logo_on)) { ?>
            <a class="standard-logo standard-logo-black " href="<?php print esc_url(home_url('/')); ?>">
                <img src="<?php print esc_url($frintem_secondary_logo); ?>"
                     alt="<?php print esc_attr('logo', 'frintem'); ?>"/>
            </a>
            <?php
        } else { ?>
            <a class="standard-logo" href="<?php print esc_url(home_url('/')); ?>">
                <img src="<?php print esc_url($frintem_site_logo); ?>"
                     alt="<?php print esc_attr('logo', 'frintem'); ?>"/>
            </a>
            <?php
        }
    }
    ?>
    <?php
}


/**
 * [frintem_header_social_profiles description]
 * @return [type] [description]
 */
function frintem_header_social_profiles()
{
    $frintem_topbar_fb_url = get_theme_mod('frintem_topbar_fb_url', __('#', 'frintem'));
    $frintem_topbar_twitter_url = get_theme_mod('frintem_topbar_twitter_url', __('#', 'frintem'));
    $frintem_topbar_instagram_url = get_theme_mod('frintem_topbar_instagram_url', __('#', 'frintem'));
    $frintem_topbar_linkedin_url = get_theme_mod('frintem_topbar_linkedin_url', __('#', 'frintem'));
    $frintem_topbar_youtube_url = get_theme_mod('frintem_topbar_youtube_url', __('#', 'frintem'));
    ?>
    <?php if (!empty($frintem_topbar_fb_url)): ?>
    <li><a target="_blank" href="<?php print esc_url($frintem_topbar_fb_url); ?>"><i class="fab fa-facebook-f"></i></a></li>
<?php endif; ?>

    <?php if (!empty($frintem_topbar_twitter_url)): ?>
    <li><a target="_blank" href="<?php print esc_url($frintem_topbar_twitter_url); ?>"><i class="fab fa-twitter"></i></a></li>
<?php endif; ?>

    <?php if (!empty($frintem_topbar_instagram_url)): ?>
    <li><a target="_blank" href="<?php print esc_url($frintem_topbar_instagram_url); ?>"><i class="fab fa-instagram"></i></a></li>
<?php endif; ?>

    <?php if (!empty($frintem_topbar_linkedin_url)): ?>
    <li><a target="_blank" href="<?php print esc_url($frintem_topbar_linkedin_url); ?>"><i class="fab fa-linkedin"></i></a></li>
<?php endif; ?>

    <?php if (!empty($frintem_topbar_youtube_url)): ?>
    <li><a target="_blank" href="<?php print esc_url($frintem_topbar_youtube_url); ?>"><i class="fab fa-youtube"></i></a></li>
<?php endif; ?>
    <?php
}


function frintem_footer_social_profiles()
{
    $frintem_footer_fb_url = get_theme_mod('frintem_footer_fb_url', __('#', 'frintem'));
    $frintem_footer_twitter_url = get_theme_mod('frintem_footer_twitter_url', __('#', 'frintem'));
    $frintem_footer_youtube_url = get_theme_mod('frintem_footer_youtube_url', __('#', 'frintem'));
    $frintem_footer_linkedin_url = get_theme_mod('frintem_footer_linkedin_url', __('#', 'frintem'));
    ?>
    <ul class="circle_social_links ul_li_right clearfix">
        <?php if ($frintem_footer_fb_url): ?>
            <li>
                <a target="_blank" class="bg_facebook" href="<?php print esc_url($frintem_footer_fb_url); ?>">
                    <i class="fab fa-facebook-f"></i>
                    <i class="fab fa-facebook-f"></i>
                </a>
            </li>
        <?php endif; ?>
        <?php if ($frintem_footer_twitter_url): ?>
            <li>
                <a target="_blank" class="bg_twitter" href="<?php print esc_url($frintem_footer_twitter_url); ?>">
                    <i class="fab fa-twitter"></i>
                    <i class="fab fa-twitter"></i>
                </a>
            </li>
        <?php endif; ?>
        <?php if ($frintem_footer_youtube_url): ?>
            <li>
                <a target="_blank" class="bg_youtube" href="<?php print esc_url($frintem_footer_youtube_url); ?>">
                    <i class="fab fa-youtube"></i>
                    <i class="fab fa-youtube"></i>
                </a>
            </li>
        <?php endif; ?>
        <?php if ($frintem_footer_linkedin_url): ?>
            <li>
                <a target="_blank" class="bg_linkedin" href="<?php print esc_url($frintem_footer_linkedin_url); ?>">
                    <i class="fab fa-linkedin"></i>
                    <i class="fab fa-linkedin"></i>
                </a>
            </li>
        <?php endif; ?>
    </ul>
    <?php
}

/**
 * [frintem_header_menu description]
 * @return [type] [description]
 */
function frintem_header_menu()
{ ?>
    <?php
    wp_nav_menu(array(
        'theme_location' => 'main-menu',
        'menu_class' => 'ul_li_center clearfix',
        'container' => '',
        'fallback_cb' => 'frintem_Navwalker_Class::fallback',
        'walker' => new frintem_Navwalker_Class
    ));
    ?>
    <?php
}

/**
 * [frintem_header_menu left description]
 * @return [type] [description]
 */
function frintem_header_left_menu()
{ ?>
    <?php
    wp_nav_menu(array(
        'theme_location' => 'main-left-menu',
        'menu_class' => '',
        'container' => '',
        'fallback_cb' => 'frintem_Navwalker_Class::fallback',
        'walker' => new frintem_Navwalker_Class
    ));
    ?>
    <?php
}

/**
 * [frintem_header_menu left description]
 * @return [type] [description]
 */
function frintem_header_right_menu()
{ ?>
    <?php
    wp_nav_menu(array(
        'theme_location' => 'main-right-menu',
        'menu_class' => '',
        'container' => '',
        'fallback_cb' => 'frintem_Navwalker_Class::fallback',
        'walker' => new frintem_Navwalker_Class
    ));
    ?>
    <?php
}


/**
 * [frintem_header_menu description]
 * @return [type] [description]
 */
function frintem_mobile_menu()
{ ?>
    <?php
    $frintem_menu = wp_nav_menu(array(
        'theme_location' => 'main-menu',
        'menu_class' => '',
        'container' => '',
        'menu_id' => 'mobile-menu-active',
        'echo' => false
    ));

    $frintem_menu = str_replace("menu-item-has-children", "menu-item-has-children has-children", $frintem_menu);
    echo wp_kses_post($frintem_menu);
    ?>
    <?php
}


function frintem_header_3_menu()
{ ?>
    <?php
    wp_nav_menu(array(
        'theme_location' => 'main-menu',
        'menu_class' => '',
        'container' => '',
    ));
    ?>
    <?php
}


/**
 * [frintem_footer_menu description]
 * @return [type] [description]
 */
function frintem_footer_menu()
{

    wp_nav_menu(array(
        'theme_location' => 'footer-menu',
        'menu_class' => 'm-0',
        'container' => '',
        'fallback_cb' => 'frintem_Navwalker_Class::fallback',
        'walker' => new frintem_Navwalker_Class
    ));

}


/**
 *
 * frintem footer
 */
add_action('frintem_footer_style', 'frintem_check_footer', 10);

function frintem_check_footer()
{
    $frintem_footer_style = function_exists('get_field') ? get_field('footer_style') : NULL;
    $frintem_default_footer_style = get_theme_mod('choose_default_footer', __('footer-style-1', 'frintem'));


    if ($frintem_footer_style == 'footer-style-1') {
        frintem_footer_style_1();
    } elseif ($frintem_footer_style == 'footer-style-2') {
        frintem_footer_style_2();
    } elseif ($frintem_footer_style == 'footer-style-3') {
        frintem_footer_style_3();
    } else {

        /** default footer style **/
        if ($frintem_default_footer_style == 'footer-style-2') {
            frintem_footer_style_2();
        } elseif ($frintem_default_footer_style == 'footer-style-3') {
            frintem_footer_style_3();
        } else {
            frintem_footer_style_1();
        }

    }
}

/**
 * footer  style_defaut
 */
function frintem_footer_style_1()
{

    $footer_bg_img = get_theme_mod('frintem_footer_bg');
    $frintem_footer_logo_switch = get_theme_mod('frintem_footer_logo_switch');
    $footer_social_switch = get_theme_mod('footer_social_switch', false);
    $frintem_copyright_center = $footer_social_switch ? 'col-lg-6 col-md-6' : 'col-md-12 text-center';
    $frintem_footer_bg_url_from_page = function_exists('get_field') ? get_field('frintem_footer_bg') : '';
    $frintem_footer_bg_color_from_page = function_exists('get_field') ? get_field('frintem_footer_bg_color') : '';
    $footer_bg_color = get_theme_mod('frintem_footer_bg_color');

    // bg image
    $bg_img = !empty($frintem_footer_bg_url_from_page['url']) ? $frintem_footer_bg_url_from_page['url'] : $footer_bg_img;

    // bg color
    $bg_color = !empty($frintem_footer_bg_color_from_page) ? $frintem_footer_bg_color_from_page : $footer_bg_color;

    // footer_columns
    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-xl-4 col-lg-6 col-md-5';
            $footer_class[2] = 'col-xl-4 col-lg-6 col-md-7';
            $footer_class[3] = 'col-xl-4 col-lg-6';
            break;
        case '4':
            $footer_class[1] = 'col-lg-2 col-md-4 col-sm-12 col-xs-12';
            $footer_class[2] = 'col-lg-2 col-md-3 col-sm-12 col-xs-12';
            $footer_class[3] = 'col-lg-4 col-md-5 col-sm-12 col-xs-12';
            $footer_class[4] = 'col-lg-3 col-md-6 col-sm-12 col-xs-12';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

    ?>

    <footer class="footer_section bg_default_blue text-white clearfix">
        <div class="container">
            <?php if (is_active_sidebar('footer-1') or is_active_sidebar('footer-2') or is_active_sidebar('footer-3') or is_active_sidebar('footer-4')): ?>
                <div class="footer_widget_area clearfix">
                    <div class="row justify-content-lg-between justify-content-md-start justify-content-sm-left">
                        <?php
                        if ($footer_columns < 4) {
                            print '<div class="col-lg-2 col-md-4 col-sm-12 col-xs-12">';
                            dynamic_sidebar('footer-1');
                            print '</div>';

                            print '<div class="col-lg-2 col-md-3 col-sm-12 col-xs-12">';
                            dynamic_sidebar('footer-2');
                            print '</div>';

                            print '<div class="col-lg-4 col-md-5 col-sm-12 col-xs-12">';
                            dynamic_sidebar('footer-3');
                            print '</div>';

                            print '<div class="col-lg-3 col-md-6 col-sm-12 col-xs-12">';
                            dynamic_sidebar('footer-4');
                            print '</div>';
                        } else {
                            for ($num = 1; $num <= $footer_columns; $num++) {
                                if (!is_active_sidebar('footer-' . $num)) continue;
                                print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                dynamic_sidebar('footer-' . $num);
                                print '</div>';
                            }
                        }

                        ?>
                    </div>
                </div>
            <?php endif; ?>

            <div class="footer_bottom_boxed clearfix">
                <div class="row align-items-center justify-content-lg-between justify-content-md-between">
                    <div class="<?php print esc_attr($frintem_copyright_center); ?>">
                        <p class="copyright_text mb-0"><?php print frintem_copyright_text(); ?></p>
                    </div>

                    <?php if (!empty($footer_social_switch)) : ?>
                        <div class="col-lg-6 col-md-6">
                            <?php frintem_footer_social_profiles(); ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>

        </div>
    </footer>


    <?php
}

/**
 * footer  style 02
 */
function frintem_footer_style_2()
{

    $footer_bg_img = get_theme_mod('frintem_footer_bg');
    $frintem_footer_logo_switch = get_theme_mod('frintem_footer_logo_switch');
    $footer_social_switch = get_theme_mod('footer_social_switch', false);
    $frintem_copyright_center = $footer_social_switch ? 'col-lg-6 col-md-6' : 'col-md-12 text-center';
    $frintem_footer_bg_url_from_page = function_exists('get_field') ? get_field('frintem_footer_bg') : '';
    $frintem_footer_bg_color_from_page = function_exists('get_field') ? get_field('frintem_footer_bg_color') : '';
    $footer_bg_color = get_theme_mod('frintem_footer_bg_color');

    // bg image
    $bg_img = !empty($frintem_footer_bg_url_from_page['url']) ? $frintem_footer_bg_url_from_page['url'] : $footer_bg_img;

    // bg color
    $bg_color = !empty($frintem_footer_bg_color_from_page) ? $frintem_footer_bg_color_from_page : $footer_bg_color;

    // footer_columns
    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-' . $num)) {
            $footer_columns++;
        }
    }

    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-xl-4 col-lg-6 col-md-5';
            $footer_class[2] = 'col-xl-4 col-lg-6 col-md-7';
            $footer_class[3] = 'col-xl-4 col-lg-6';
            break;
        case '4':
            $footer_class[1] = 'col-lg-2 col-md-4 col-sm-12 col-xs-12';
            $footer_class[2] = 'col-lg-2 col-md-4 col-sm-12 col-xs-12';
            $footer_class[3] = 'col-lg-4 col-md-4 col-sm-12 col-xs-12';
            $footer_class[4] = 'col-lg-3 col-md-12 col-sm-12 col-xs-12';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

    ?>

    <footer class="footer_section footer-style-02 bg_gray clearfix">
        <div class="container">
            <?php if (is_active_sidebar('footer-2-1') or is_active_sidebar('footer-2-2') or is_active_sidebar('footer-2-3') or is_active_sidebar('footer-2-4')): ?>
                <div class="footer_widget_area clearfix">
                    <div class="row justify-content-lg-between justify-content-md-center justify-content-sm-center">
                        <?php
                        if ($footer_columns < 4) {
                            print '<div class="col-lg-2 col-md-4 col-sm-12 col-xs-12">';
                            dynamic_sidebar('footer-2-1');
                            print '</div>';

                            print '<div class="col-lg-2 col-md-4 col-sm-12 col-xs-12">';
                            dynamic_sidebar('footer-2-2');
                            print '</div>';

                            print '<div class="col-lg-4 col-md-4 col-sm-12 col-xs-12">';
                            dynamic_sidebar('footer-2-3');
                            print '</div>';

                            print '<div class="col-lg-3 col-md-12 col-sm-12 col-xs-12">';
                            dynamic_sidebar('footer-2-4');
                            print '</div>';
                        } else {
                            for ($num = 1; $num <= $footer_columns; $num++) {
                                if (!is_active_sidebar('footer-2-' . $num)) continue;
                                print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                dynamic_sidebar('footer-2-' . $num);
                                print '</div>';
                            }
                        }

                        ?>
                    </div>
                </div>
            <?php endif; ?>

            <div class="footer_bottom_boxed bg_white clearfix">
                <div class="row align-items-center justify-content-lg-between justify-content-md-between">
                    <div class="<?php print esc_attr($frintem_copyright_center); ?>">
                        <p class="copyright_text mb-0"><?php print frintem_copyright_text(); ?></p>
                    </div>

                    <?php if (!empty($footer_social_switch)) : ?>
                        <div class="col-lg-6 col-md-6">
                            <?php frintem_footer_social_profiles(); ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>

        </div>
    </footer>


    <?php
}


/**
 * footer  style 03
 */
function frintem_footer_style_3()
{
    $footer_bg_img = get_theme_mod('frintem_footer_bg');
    $frintem_footer_logo = get_theme_mod('frintem_footer_logo');
    $frintem_footer_text = get_theme_mod('frintem_footer_text', 'Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium dolorem que laudantium, totam rem aperiam eaque ipsa quae abillo inventore veritatis quasi architecto beatae vitae dicta ');
    $frintem_footer_newsletter_text = get_theme_mod('frintem_footer_newsletter_text', 'Get More Update Join Our Newsletters');
    $frintem_footer_shortcode = get_theme_mod('frintem_footer_shortcode');
    $frintem_footer_fb_url = get_theme_mod('frintem_footer_fb_url', __('#', 'frintem'));
    $frintem_footer_twitter_url = get_theme_mod('frintem_footer_twitter_url', __('#', 'frintem'));
    $frintem_footer_youtube_url = get_theme_mod('frintem_footer_youtube_url', __('#', 'frintem'));
    $frintem_footer_linkedin_url = get_theme_mod('frintem_footer_linkedin_url', __('#', 'frintem'));


    $frintem_footer_bg_url_from_page = function_exists('get_field') ? get_field('frintem_footer_bg') : '';
    $frintem_footer_bg_color_from_page = function_exists('get_field') ? get_field('frintem_footer_bg_color') : '';
    $footer_bg_color = get_theme_mod('frintem_footer_bg_color');

    // bg image
    $bg_img = !empty($frintem_footer_bg_url_from_page['url']) ? $frintem_footer_bg_url_from_page['url'] : $footer_bg_img;
    // bg color
    $bg_color = !empty($frintem_footer_bg_color_from_page) ? $frintem_footer_bg_color_from_page : $footer_bg_color;

    $footer_columns = 0;
    $footer_widgets = get_theme_mod('footer_widget_number', 4);

    for ($num = 1; $num <= $footer_widgets; $num++) {
        if (is_active_sidebar('footer-3-' . $num)) {
            $footer_columns++;
        }
    }


    switch ($footer_columns) {
        case '1':
            $footer_class[1] = 'col-lg-12';
            break;
        case '2':
            $footer_class[1] = 'col-lg-6 col-md-6';
            $footer_class[2] = 'col-lg-6 col-md-6';
            break;
        case '3':
            $footer_class[1] = 'col-lg-3 col-md-6 col-sm-12 col-xs-12';
            $footer_class[2] = 'col-lg-4 col-md-6 col-sm-12 col-xs-12';
            $footer_class[3] = 'col-lg-5 col-md-12 col-sm-12 col-xs-12';
            break;
        default:
            $footer_class = 'col-xl-4 col-lg-4 col-md-6';
            break;
    }

    ?>

    <footer class="footer_section secondary_footer bg_black text-white clearfix">
        <div class="container">
            <div class="row justify-content-lg-between justify-content-md-center justify-content-sm-center">

                <div class="col-lg-4 col-md-8">
                    <div class="footer_about bg_black">
                        <?php if (!empty($frintem_footer_logo)): ?>
                            <div class="brand_logo bg_default_yellow">
                                <a href="<?php print esc_url(home_url('/')); ?>">
                                    <img src="<?php print esc_url($frintem_footer_logo); ?>" alt="logo_not_found">
                                </a>
                            </div>
                        <?php endif; ?>
                        <?php if (!empty($frintem_footer_text)): ?>
                            <p class="mb_30">
                                <?php print esc_html($frintem_footer_text); ?>
                            </p>
                        <?php endif; ?>
                        <ul class="circle_social_links ul_li mb_80 clearfix">
                            <?php if ($frintem_footer_fb_url): ?>
                                <li>
                                    <a class="bg_facebook" href="<?php print esc_url($frintem_footer_fb_url); ?>">
                                        <i class="fab fa-facebook-f"></i>
                                        <i class="fab fa-facebook-f"></i>
                                    </a>
                                </li>
                            <?php endif; ?>
                            <?php if ($frintem_footer_twitter_url): ?>
                                <li>
                                    <a class="bg_twitter" href="<?php print esc_url($frintem_footer_twitter_url); ?>">
                                        <i class="fab fa-twitter"></i>
                                        <i class="fab fa-twitter"></i>
                                    </a>
                                </li>
                            <?php endif; ?>
                            <?php if ($frintem_footer_youtube_url): ?>
                                <li>
                                    <a class="bg_youtube" href="<?php print esc_url($frintem_footer_youtube_url); ?>">
                                        <i class="fab fa-youtube"></i>
                                        <i class="fab fa-youtube"></i>
                                    </a>
                                </li>
                            <?php endif; ?>
                            <?php if ($frintem_footer_linkedin_url): ?>
                                <li>
                                    <a class="bg_linkedin" href="<?php print esc_url($frintem_footer_linkedin_url); ?>">
                                        <i class="fab fa-linkedin"></i>
                                        <i class="fab fa-linkedin"></i>
                                    </a>
                                </li>
                            <?php endif; ?>
                        </ul>
                        <div class="copyright_text bg_black">
                            <p class="mb-0"><?php print frintem_copyright_text(); ?></p>
                        </div>
                    </div>
                </div>

                <div class="col-lg-8 col-md-8">
                    <div class="footer_widget_area">
                        <div class="row justify-content-lg-between">
                            <?php
                            if ($footer_columns < 3) {
                                print '<div class="col-lg-3 col-md-6 col-sm-12 col-xs-12">';
                                dynamic_sidebar('footer-3-1');
                                print '</div>';

                                print '<div class="col-lg-4 col-md-6 col-sm-12 col-xs-12">';
                                dynamic_sidebar('footer-3-2');
                                print '</div>';

                                print '<div class="col-lg-5 col-md-12 col-sm-12 col-xs-12">';
                                dynamic_sidebar('footer-3-3');
                                print '</div>';
                            } else {
                                for ($num = 1; $num <= $footer_columns; $num++) {
                                    if (!is_active_sidebar('footer-3-' . $num)) continue;
                                    print '<div class="' . esc_attr($footer_class[$num]) . '">';
                                    dynamic_sidebar('footer-3-' . $num);
                                    print '</div>';
                                }
                            }

                            ?>
                        </div>
                        <div class="footer_newsletter_boxed">
                            <div class="row justify-content-lg-between">
                                <div class="col-lg-5 col-md-12 col-sm-12 col-xs-12">
                                    <h3 class="newsletter_title"><?php print esc_html($frintem_footer_newsletter_text); ?></h3>
                                </div>
                                <div class="col-lg-7 col-md-12 col-sm-12 col-xs-12">
                                    <?php print do_shortcode($frintem_footer_shortcode); ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

            </div>
        </div>

        <div class="border_shapes"
             data-background="<?php echo get_template_directory_uri(); ?>/assets/images/shapes/borders_shape.png"></div>
    </footer>

    <?php
}


function frintem_copyright_text()
{
    if (rtl_enable()) {
        print get_theme_mod('frintem_copyright_rtl', esc_html__('Copyright ©2020 BDevs. All Rights Reserved', 'frintem'));
    } else {
        print get_theme_mod('frintem_copyright', esc_html__('Copyright ©2020 BDevs. All Rights Reserved', 'frintem'));
    }
}


/**
 * [frintem_header_lang img description]
 * @return [type] [description]
 */
function frintem_header_lang_defualt()
{
    $frintem_header_lang = get_theme_mod('frintem_header_lang', false);
    if ($frintem_header_lang): ?>

        <ul class="lang-wrap">
            <li><a href="#0"><?php print esc_html__('English', 'frintem'); ?> <i class="far fa-angle-down"></i></a>
                <?php do_action('frintem_img_language'); ?>
            </li>
        </ul>

    <?php endif; ?>
    <?php
}


/**
 * [frintem_language_list description]
 * @return [type] [description]
 */
function _frintem_img_language($mar)
{
    return $mar;
}

function frintem_language_img_list()
{

    $mar = '';
    $languages = apply_filters('wpml_active_languages', NULL, 'orderby=id&order=desc');
    if (!empty($languages)) {
        $mar = '<ul class="lang-wrap">';
        foreach ($languages as $lan) {
            $active = $lan['active'] == 1 ? 'active' : '';
            $mar .= '<li class="' . $active . '"><a href="' . $lan['url'] . '">' . $lan['translated_name'] . '</a></li>';
        }
        $mar .= '</ul>';
    } else {
        //remove this code when send themeforest reviewer team
        $mar .= '<ul>';
        $mar .= '<li><a href="#">' . esc_html__('English', 'frintem') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('Arabic', 'frintem') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('France', 'frintem') . '</a></li>';
        $mar .= '<li><a href="#">' . esc_html__('Bangla', 'frintem') . '</a></li>';
        $mar .= ' </ul>';
    }
    print _frintem_img_language($mar);
}

add_action('frintem_img_language', 'frintem_language_img_list');


/**
 * [frintem_breadcrumb_func description]
 * @return [type] [description]
 */
function frintem_breadcrumb_func()
{

    $breadcrumb_class = '';
    $breadcrumb_show = 1;

    if (is_front_page() && is_home()) {
        $title = get_theme_mod('breadcrumb_blog_title', __('Blog', 'frintem'));
        $breadcrumb_class = 'home_front_page';

    } elseif (is_front_page()) {
        $title = get_theme_mod('breadcrumb_blog_title', __('Blog', 'frintem'));
        $breadcrumb_show = 0;

    } elseif (is_home()) {
        if (get_option('page_for_posts')) {
            $title = !empty(get_theme_mod('breadcrumb_blog_title')) ? get_theme_mod('breadcrumb_blog_title') : get_the_title(get_option('page_for_posts'));
        }
    } elseif (is_single() && 'post' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_blog_title_details_rtl', __('Blog', 'frintem'));
        else
            $title = !empty(get_theme_mod('breadcrumb_blog_title_details')) ? get_theme_mod('breadcrumb_blog_title_details') : get_the_title();
    } elseif (is_single() && 'product' == get_post_type()) {
        $title = get_theme_mod('breadcrumb_product_details', __('Shop', 'frintem'));
    } elseif (is_single() && 'bdevs-services' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_department_details_rtl', __('Services', 'frintem'));
        else
            $title = get_the_title();

    } elseif (is_single() && 'bdevs-doctor' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_doctor_details_rtl', __('Doctor Details', 'frintem'));
        else
            $title = get_theme_mod('breadcrumb_doctor_details', __('Doctor Details', 'frintem'));

    } elseif (is_single() && 'bdevs-case_study' == get_post_type()) {
        if (rtl_enable())
            $title = get_theme_mod('breadcrumb_case_study_details_rtl', __('Gallery', 'frintem'));
        else
            $title = get_theme_mod('breadcrumb_case_study_details', __('Gallery', 'frintem'));

    } elseif (is_search()) {
        $title = esc_html__('Search Results for : ', 'frintem') . get_search_query();
    } elseif (is_404()) {
        $title = esc_html__('Page not Found', 'frintem');
    } elseif (function_exists('is_woocommerce') && is_woocommerce()) {
        $title = get_theme_mod('breadcrumb_shop', esc_html__('Shop', 'frintem'));
    } elseif (is_archive()) {
        $title = get_the_archive_title();
    } else {
        $title = get_the_title();
    }

    $is_breadcrumb = function_exists('get_field') ? get_field('is_it_invisible_breadcrumb') : '';


    if (empty($is_breadcrumb) && $breadcrumb_show == 1) {

        $bg_img_from_page = function_exists('get_field') ? get_field('breadcrumb_background_image') : '';
        $hide_bg_img = function_exists('get_field') ? get_field('hide_breadcrumb_background_image') : '';
        $back_title = function_exists('get_field') ? get_field('breadcrumb_back_title') : '';

        // get_theme_mod
        $bg_img = get_theme_mod('breadcrumb_bg_img');


        if ($hide_bg_img) {
            $bg_img = '';
        } else {
            $bg_img = !empty($bg_img_from_page) ? $bg_img_from_page['url'] : $bg_img;
        } ?>


        <section class="breadcrumb_section d-flex align-items-center clearfix breadcrumb-spacings <?php print esc_attr($breadcrumb_class); ?>"
                data-background="<?php print esc_attr($bg_img); ?>">
            <div class="container">
                <div class="row align-items-center justify-content-lg-between">
                    <div class="col-lg-12 text-center" data-wow-delay=".1s">
                        <h1 class="page_title"><?php echo wp_kses_post($title); ?></h1>
                        <div class="breadcrumb-menu">
                            <?php frintem_breadcrumb_callback(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </section>

        <?php
    }
}

add_action('frintem_before_main_content', 'frintem_breadcrumb_func');


function frintem_breadcrumb_callback()
{
    $args = array(
        'show_browse' => false,
        'post_taxonomy' => array('product' => 'product_cat')
    );
    $breadcrumb = new Frintem_Breadcrumb($args);

    return $breadcrumb->trail();
}


// gru_search_form
function frintem_search_form()
{ ?>
    <!-- Modal Search -->
    <div class="search-wrap d-none">
        <div class="search-inner">
            <i class="fal fa-times search-close" id="search-close"></i>
            <div class="search-cell">
                <form method="get" action="<?php print esc_url(home_url('/')); ?>">
                    <div class="search-field-holder">
                        <input type="search" name="s" class="main-search-input"
                               value="<?php print esc_attr(get_search_query()) ?>"
                               placeholder="<?php print esc_attr('Search Your Keyword...', 'frintem'); ?>">
                    </div>
                </form>
            </div>
        </div>
    </div>

    <?php
}

add_action('frintem_before_main_content', 'frintem_search_form');

/**
 *
 * pagination
 */
if (!function_exists('frintem_pagination')) {

    function _frintem_pagi_callback($pagination)
    {
        return $pagination;
    }

    //page navegation
    function frintem_pagination($prev, $next, $pages, $args)
    {
        global $wp_query, $wp_rewrite;
        $menu = '';
        $wp_query->query_vars['paged'] > 1 ? $current = $wp_query->query_vars['paged'] : $current = 1;

        if ($pages == '') {
            global $wp_query;
            $pages = $wp_query->max_num_pages;

            if (!$pages)
                $pages = 1;
        }

        $pagination = array(
            'base' => add_query_arg('paged', '%#%'),
            'format' => '',
            'total' => $pages,
            'current' => $current,
            'prev_text' => $prev,
            'next_text' => $next,
            'type' => 'array'
        );

        //rewrite permalinks
        if ($wp_rewrite->using_permalinks())
            $pagination['base'] = user_trailingslashit(trailingslashit(remove_query_arg('s', get_pagenum_link(1))) . 'page/%#%/', 'paged');

        if (!empty($wp_query->query_vars['s']))
            $pagination['add_args'] = array('s' => get_query_var('s'));

        $pagi = '';
        if (paginate_links($pagination) != '') {
            $paginations = paginate_links($pagination);
            $pagi .= '<ul>';
            foreach ($paginations as $key => $pg) {
                $pagi .= '<li>' . $pg . '</li>';
            }
            $pagi .= '</ul>';
        }

        print _frintem_pagi_callback($pagi);
    }
}


// rtl_enable
function rtl_enable()
{
    $my_current_lang = apply_filters('wpml_current_language', NULL);
    $rtl_enable = get_theme_mod('rtl_switch', false);
    if ($my_current_lang != 'en' && $rtl_enable) {
        return true;
    } else {
        return false;
    }
}


// scrollup
function frintem_scrollup_switch()
{
    $scrollup_switch = get_theme_mod('frintem_scrollup_switch', false);
    wp_enqueue_style('frintem-custom', FRINTEM_THEME_CSS_DIR . 'frintem-custom.css', array());
    if ($scrollup_switch) {
        $custom_css = '';
        $custom_css .= "#scrollUp{ display: none !important;}";

        wp_add_inline_style('frintem-scrollup-switch', $custom_css);
    }
}

add_action('wp_enqueue_scripts', 'frintem_scrollup_switch');


// frintem_kses_intermediate
function frintem_kses_intermediate($string = '')
{
    return wp_kses($string, frintem_get_allowed_html_tags('intermediate'));
}

function frintem_get_allowed_html_tags($level = 'basic')
{
    $allowed_html = [
        'b' => [],
        'i' => [],
        'u' => [],
        'em' => [],
        'br' => [],
        'abbr' => [
            'title' => [],
        ],
        'span' => [
            'class' => [],
        ],
        'strong' => [],
        'a' => [
            'href' => [],
            'title' => [],
            'class' => [],
            'id' => []
        ]
    ];

    return $allowed_html;
}

// header top bg color
function frintem_breadcrumb_bg_color()
{
    $color_code = get_theme_mod('frintem_breadcrumb_bg_color', __('#222', 'frintem'));
    wp_enqueue_style('frintem-custom-breadcrumb-bg-color', FRINTEM_THEME_CSS_DIR . 'frintem-custom.css', array());
    if ($color_code != '') {
        $custom_css = '';
        $custom_css .= ".breadcrumb_section{ background-color: " . $color_code . "}";
        wp_add_inline_style('frintem-custom-breadcrumb-bg-color', $custom_css);
    }
}

add_action('wp_enqueue_scripts', 'frintem_breadcrumb_bg_color');

// breadcrumb-spacing top
function frintem_breadcrumb_spacing()
{
    $padding_px = get_theme_mod('frintem_breadcrumb_spacing', __('160px', 'frintem'));
    wp_enqueue_style('frintem-breadcrumb-top-spacing', FRINTEM_THEME_CSS_DIR . 'frintem-custom.css', array());
    if ($padding_px != '') {
        $custom_css = '';
        $custom_css .= ".breadcrumb-spacings{ padding-top: " . $padding_px . "}";

        wp_add_inline_style('frintem-breadcrumb-top-spacing', $custom_css);
    }
}

add_action('wp_enqueue_scripts', 'frintem_breadcrumb_spacing');

// breadcrumb-spacing bottom
function frintem_breadcrumb_bottom_spacing()
{
    $padding_px = get_theme_mod('frintem_breadcrumb_bottom_spacing', __('160px', 'frintem'));
    wp_enqueue_style('frintem-breadcrumb-bottom-spacing', FRINTEM_THEME_CSS_DIR . 'frintem-custom.css', array());
    if ($padding_px != '') {
        $custom_css = '';
        $custom_css .= ".breadcrumb-spacings{ padding-bottom: " . $padding_px . "}";

        wp_add_inline_style('frintem-breadcrumb-bottom-spacing', $custom_css);
    }
}

add_action('wp_enqueue_scripts', 'frintem_breadcrumb_bottom_spacing');

// theme color 1
function frintem_custom_color()
{
    $color_code = get_theme_mod('frintem_color_option', '#fec931');
    wp_enqueue_style('frintem-custom-color', FRINTEM_THEME_CSS_DIR . 'frintem-custom.css', array());
    if ($color_code != '') {
        $custom_css = '';
        // bg
        $custom_css .= ".blog-post-tag a:hover,.custom_btn.btn_border span.bg_default_yellow,.service_grid .icon_btn,.portfolio_fullimage .icon_btn:before,.newsletter_boxed .icon_btn:before,.feature_listlayout_boxed2:hover .item_icon,.home_three_slider .small_title:before,.icon_btn,.blog_fullimage_2 .text_btn span:before,.creative_testimonial_carousel .owl-nav .owl-next:before, .creative_testimonial_carousel .owl-nav .owl-prev:before,.bg_default_yellow,.custom_btn.bg_default_orange:before,.bg_default_yellow,.home_two_banner .sub_title:before{ background: " . $color_code . "}";
        // color
        $custom_css .= ".home_three_slider .small_title,.secondary_footer.text-white a:hover,.feeds-date i,.blog_fullimage_2:hover .item_title > a,.blog_fullimage_2 .post_meta a:hover,.check_info_list > li:before, .outline_check_info_list > li:before,.main_menu > ul > li:hover > a, .main_menu > ul > li.active > a,.home_two_banner .sub_title{ color: " . $color_code . "}";

        $custom_css .= ".footer_newsletter_boxed input:focus,.border_left_yellow{ border-color: " . $color_code . "}";
        wp_add_inline_style('frintem-custom-color', $custom_css);
    }
}

add_action('wp_enqueue_scripts', 'frintem_custom_color');

// theme color 2
function frintem_custom_color_2()
{
    $color_code = get_theme_mod('frintem_color_option_2', '#ff4328');
    wp_enqueue_style('frintem-custom-color-2', FRINTEM_THEME_CSS_DIR . 'frintem-custom.css', array());
    if ($color_code != '') {
        $custom_css = '';
        // bg
        $custom_css .= ".update-cart > a:hover, .coupon-left button:hover,.blog-post-tag a,.sidebar-tad li a:hover, .tagcloud a:hover,.sidebar-search-form button,.widget .widget-title::after,.description_tabnav a:before,.site-btn,.basic-pagination-2 ul li a:hover, .basic-pagination-2 ul li.active a,.basic-pagination-2 ul li span:hover, .basic-pagination ul li span.current,.product-action a:hover,.contact-info i,.custom_btn.btn_border span.bg_default_orange,.service_grid .icon_btn:before,.portfolio_fullimage .icon_btn,.admin_image i,.newsletter_boxed .icon_btn:before,.newsletter_boxed .icon_btn,.feature_listlayout_boxed2:hover,.feature_listlayout_boxed2 .item_icon,.cart_btn .cart_counter,.icon_btn:before,.testimonial_carousel:before,.about_image_2:before,.home_one_banner .sub_title:before,.select_option > .lang-wrap > li > a,.footer_contact_form .form_item .submit_btn,.text_btn span:before,.orange_shape,.creative_testimonial_carousel .owl-nav .owl-next:hover:before, .creative_testimonial_carousel .owl-nav .owl-prev:hover:before,.text_btn span:before,.bg_default_orange,.custom_btn.bg_default_yellow:before{ background: " . $color_code . "}";
        // color
        $custom_css .= ".lang-wrap li ul li:hover > a,.woocommerce a.added_to_cart,.widget li a:hover,.post-meta span a:hover,.post-meta span i,.widget-posts-title a:hover,.description_tabnav a:hover, .description_tabnav a.active,.rating a,.pro-title a:hover,.faq_accordion .card-header button:before,.pricing_plan .sub_title,.select_option .nice-select:after,.form_item .input_icon,.sb_service_category a:hover,.header_section_5 .main_menu > ul > li:hover > a, .header_section_5 .main_menu > ul > li.active > a,.header_section_5.stuck .main_menu > ul > li.active > a,.team_grid .member_title,.service_card .item_type,.feature_listlayout_boxed2 .item_type,.text_btn:hover i,.play_btn,.header_icon_btns li button:hover, .header_icon_btns li button.active,.secondary_header .main_menu > ul > li:hover > a, .secondary_header .main_menu > ul > li.active > a,.post_meta i,.post_meta a:hover,.blog_grid_1 .post_date i,.blog_grid_1:hover .item_title > a,a,.circle_check_info_list > li:before,.whatwedo_content p .big_text,.home_one_banner .sub_title,.header_contact_info li i,#scroll,.footer_hotline i,.footer-widget ul li a:hover,.price-list li i,.testimonial_primary .hero_title,.avatar_wrap .avatar_title,.section_title .small_title,.play_btn.bg_white,.feature_card .item_type,.section_title .small_title,.main_menu .has_child .submenu li:hover > a, .main_menu .has_child .submenu li.active > a{ color: " . $color_code . "}";

        $custom_css .= ".update-cart > a:hover, .coupon-left button:hover,.comment-form textarea:focus,.basic-pagination-2 ul li a:hover, .basic-pagination-2 ul li.active a,.basic-pagination-2 ul li span:hover, .basic-pagination ul li span.current,.border_left_orange{ border-color: " . $color_code . "}";
        $custom_css .= ".preloader .spinner{ border-top-color: " . $color_code . "}";
        wp_add_inline_style('frintem-custom-color-2', $custom_css);
    }
}

add_action('wp_enqueue_scripts', 'frintem_custom_color_2');